/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Intrinsic Function Source Fragment                                         *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_IR_INTRINSIC_VE_ENUMS_H
#define LLVM_IR_INTRINSIC_VE_ENUMS_H
namespace llvm::Intrinsic {
enum VEIntrinsics : unsigned {
// Enum values for intrinsics.
    ve_vl_andm_MMM = 13047,                            // llvm.ve.vl.andm.MMM (IntrinsicsVEVL.gen.td:1236)
    ve_vl_andm_mmm,                            // llvm.ve.vl.andm.mmm (IntrinsicsVEVL.gen.td:1235)
    ve_vl_eqvm_MMM,                            // llvm.ve.vl.eqvm.MMM (IntrinsicsVEVL.gen.td:1242)
    ve_vl_eqvm_mmm,                            // llvm.ve.vl.eqvm.mmm (IntrinsicsVEVL.gen.td:1241)
    ve_vl_extract_vm512l,                      // llvm.ve.vl.extract.vm512l (IntrinsicsVE.td:16)
    ve_vl_extract_vm512u,                      // llvm.ve.vl.extract.vm512u (IntrinsicsVE.td:12)
    ve_vl_fencec_s,                            // llvm.ve.vl.fencec.s (IntrinsicsVEVL.gen.td:1256)
    ve_vl_fencei,                              // llvm.ve.vl.fencei (IntrinsicsVEVL.gen.td:1254)
    ve_vl_fencem_s,                            // llvm.ve.vl.fencem.s (IntrinsicsVEVL.gen.td:1255)
    ve_vl_fidcr_sss,                           // llvm.ve.vl.fidcr.sss (IntrinsicsVEVL.gen.td:1253)
    ve_vl_insert_vm512l,                       // llvm.ve.vl.insert.vm512l (IntrinsicsVE.td:25)
    ve_vl_insert_vm512u,                       // llvm.ve.vl.insert.vm512u (IntrinsicsVE.td:20)
    ve_vl_lcr_sss,                             // llvm.ve.vl.lcr.sss (IntrinsicsVEVL.gen.td:1250)
    ve_vl_lsv_vvss,                            // llvm.ve.vl.lsv.vvss (IntrinsicsVEVL.gen.td:83)
    ve_vl_lvm_MMss,                            // llvm.ve.vl.lvm.MMss (IntrinsicsVEVL.gen.td:88)
    ve_vl_lvm_mmss,                            // llvm.ve.vl.lvm.mmss (IntrinsicsVEVL.gen.td:87)
    ve_vl_lvsd_svs,                            // llvm.ve.vl.lvsd.svs (IntrinsicsVEVL.gen.td:85)
    ve_vl_lvsl_svs,                            // llvm.ve.vl.lvsl.svs (IntrinsicsVEVL.gen.td:84)
    ve_vl_lvss_svs,                            // llvm.ve.vl.lvss.svs (IntrinsicsVEVL.gen.td:86)
    ve_vl_lzvm_sml,                            // llvm.ve.vl.lzvm.sml (IntrinsicsVEVL.gen.td:1248)
    ve_vl_negm_MM,                             // llvm.ve.vl.negm.MM (IntrinsicsVEVL.gen.td:1246)
    ve_vl_negm_mm,                             // llvm.ve.vl.negm.mm (IntrinsicsVEVL.gen.td:1245)
    ve_vl_nndm_MMM,                            // llvm.ve.vl.nndm.MMM (IntrinsicsVEVL.gen.td:1244)
    ve_vl_nndm_mmm,                            // llvm.ve.vl.nndm.mmm (IntrinsicsVEVL.gen.td:1243)
    ve_vl_orm_MMM,                             // llvm.ve.vl.orm.MMM (IntrinsicsVEVL.gen.td:1238)
    ve_vl_orm_mmm,                             // llvm.ve.vl.orm.mmm (IntrinsicsVEVL.gen.td:1237)
    ve_vl_pack_f32a,                           // llvm.ve.vl.pack.f32a (IntrinsicsVE.td:8)
    ve_vl_pack_f32p,                           // llvm.ve.vl.pack.f32p (IntrinsicsVE.td:5)
    ve_vl_pcvm_sml,                            // llvm.ve.vl.pcvm.sml (IntrinsicsVEVL.gen.td:1247)
    ve_vl_pfchv_ssl,                           // llvm.ve.vl.pfchv.ssl (IntrinsicsVEVL.gen.td:81)
    ve_vl_pfchvnc_ssl,                         // llvm.ve.vl.pfchvnc.ssl (IntrinsicsVEVL.gen.td:82)
    ve_vl_pvadds_vsvMvl,                       // llvm.ve.vl.pvadds.vsvMvl (IntrinsicsVEVL.gen.td:144)
    ve_vl_pvadds_vsvl,                         // llvm.ve.vl.pvadds.vsvl (IntrinsicsVEVL.gen.td:141)
    ve_vl_pvadds_vsvvl,                        // llvm.ve.vl.pvadds.vsvvl (IntrinsicsVEVL.gen.td:142)
    ve_vl_pvadds_vvvMvl,                       // llvm.ve.vl.pvadds.vvvMvl (IntrinsicsVEVL.gen.td:143)
    ve_vl_pvadds_vvvl,                         // llvm.ve.vl.pvadds.vvvl (IntrinsicsVEVL.gen.td:139)
    ve_vl_pvadds_vvvvl,                        // llvm.ve.vl.pvadds.vvvvl (IntrinsicsVEVL.gen.td:140)
    ve_vl_pvaddu_vsvMvl,                       // llvm.ve.vl.pvaddu.vsvMvl (IntrinsicsVEVL.gen.td:126)
    ve_vl_pvaddu_vsvl,                         // llvm.ve.vl.pvaddu.vsvl (IntrinsicsVEVL.gen.td:123)
    ve_vl_pvaddu_vsvvl,                        // llvm.ve.vl.pvaddu.vsvvl (IntrinsicsVEVL.gen.td:124)
    ve_vl_pvaddu_vvvMvl,                       // llvm.ve.vl.pvaddu.vvvMvl (IntrinsicsVEVL.gen.td:125)
    ve_vl_pvaddu_vvvl,                         // llvm.ve.vl.pvaddu.vvvl (IntrinsicsVEVL.gen.td:121)
    ve_vl_pvaddu_vvvvl,                        // llvm.ve.vl.pvaddu.vvvvl (IntrinsicsVEVL.gen.td:122)
    ve_vl_pvand_vsvMvl,                        // llvm.ve.vl.pvand.vsvMvl (IntrinsicsVEVL.gen.td:373)
    ve_vl_pvand_vsvl,                          // llvm.ve.vl.pvand.vsvl (IntrinsicsVEVL.gen.td:370)
    ve_vl_pvand_vsvvl,                         // llvm.ve.vl.pvand.vsvvl (IntrinsicsVEVL.gen.td:371)
    ve_vl_pvand_vvvMvl,                        // llvm.ve.vl.pvand.vvvMvl (IntrinsicsVEVL.gen.td:372)
    ve_vl_pvand_vvvl,                          // llvm.ve.vl.pvand.vvvl (IntrinsicsVEVL.gen.td:368)
    ve_vl_pvand_vvvvl,                         // llvm.ve.vl.pvand.vvvvl (IntrinsicsVEVL.gen.td:369)
    ve_vl_pvbrd_vsMvl,                         // llvm.ve.vl.pvbrd.vsMvl (IntrinsicsVEVL.gen.td:105)
    ve_vl_pvbrd_vsl,                           // llvm.ve.vl.pvbrd.vsl (IntrinsicsVEVL.gen.td:103)
    ve_vl_pvbrd_vsvl,                          // llvm.ve.vl.pvbrd.vsvl (IntrinsicsVEVL.gen.td:104)
    ve_vl_pvbrv_vvMvl,                         // llvm.ve.vl.pvbrv.vvMvl (IntrinsicsVEVL.gen.td:445)
    ve_vl_pvbrv_vvl,                           // llvm.ve.vl.pvbrv.vvl (IntrinsicsVEVL.gen.td:443)
    ve_vl_pvbrv_vvvl,                          // llvm.ve.vl.pvbrv.vvvl (IntrinsicsVEVL.gen.td:444)
    ve_vl_pvbrvlo_vvl,                         // llvm.ve.vl.pvbrvlo.vvl (IntrinsicsVEVL.gen.td:437)
    ve_vl_pvbrvlo_vvmvl,                       // llvm.ve.vl.pvbrvlo.vvmvl (IntrinsicsVEVL.gen.td:439)
    ve_vl_pvbrvlo_vvvl,                        // llvm.ve.vl.pvbrvlo.vvvl (IntrinsicsVEVL.gen.td:438)
    ve_vl_pvbrvup_vvl,                         // llvm.ve.vl.pvbrvup.vvl (IntrinsicsVEVL.gen.td:440)
    ve_vl_pvbrvup_vvmvl,                       // llvm.ve.vl.pvbrvup.vvmvl (IntrinsicsVEVL.gen.td:442)
    ve_vl_pvbrvup_vvvl,                        // llvm.ve.vl.pvbrvup.vvvl (IntrinsicsVEVL.gen.td:441)
    ve_vl_pvcmps_vsvMvl,                       // llvm.ve.vl.pvcmps.vsvMvl (IntrinsicsVEVL.gen.td:307)
    ve_vl_pvcmps_vsvl,                         // llvm.ve.vl.pvcmps.vsvl (IntrinsicsVEVL.gen.td:304)
    ve_vl_pvcmps_vsvvl,                        // llvm.ve.vl.pvcmps.vsvvl (IntrinsicsVEVL.gen.td:305)
    ve_vl_pvcmps_vvvMvl,                       // llvm.ve.vl.pvcmps.vvvMvl (IntrinsicsVEVL.gen.td:306)
    ve_vl_pvcmps_vvvl,                         // llvm.ve.vl.pvcmps.vvvl (IntrinsicsVEVL.gen.td:302)
    ve_vl_pvcmps_vvvvl,                        // llvm.ve.vl.pvcmps.vvvvl (IntrinsicsVEVL.gen.td:303)
    ve_vl_pvcmpu_vsvMvl,                       // llvm.ve.vl.pvcmpu.vsvMvl (IntrinsicsVEVL.gen.td:289)
    ve_vl_pvcmpu_vsvl,                         // llvm.ve.vl.pvcmpu.vsvl (IntrinsicsVEVL.gen.td:286)
    ve_vl_pvcmpu_vsvvl,                        // llvm.ve.vl.pvcmpu.vsvvl (IntrinsicsVEVL.gen.td:287)
    ve_vl_pvcmpu_vvvMvl,                       // llvm.ve.vl.pvcmpu.vvvMvl (IntrinsicsVEVL.gen.td:288)
    ve_vl_pvcmpu_vvvl,                         // llvm.ve.vl.pvcmpu.vvvl (IntrinsicsVEVL.gen.td:284)
    ve_vl_pvcmpu_vvvvl,                        // llvm.ve.vl.pvcmpu.vvvvl (IntrinsicsVEVL.gen.td:285)
    ve_vl_pvcvtsw_vvl,                         // llvm.ve.vl.pvcvtsw.vvl (IntrinsicsVEVL.gen.td:819)
    ve_vl_pvcvtsw_vvvl,                        // llvm.ve.vl.pvcvtsw.vvvl (IntrinsicsVEVL.gen.td:820)
    ve_vl_pvcvtws_vvMvl,                       // llvm.ve.vl.pvcvtws.vvMvl (IntrinsicsVEVL.gen.td:805)
    ve_vl_pvcvtws_vvl,                         // llvm.ve.vl.pvcvtws.vvl (IntrinsicsVEVL.gen.td:803)
    ve_vl_pvcvtws_vvvl,                        // llvm.ve.vl.pvcvtws.vvvl (IntrinsicsVEVL.gen.td:804)
    ve_vl_pvcvtwsrz_vvMvl,                     // llvm.ve.vl.pvcvtwsrz.vvMvl (IntrinsicsVEVL.gen.td:808)
    ve_vl_pvcvtwsrz_vvl,                       // llvm.ve.vl.pvcvtwsrz.vvl (IntrinsicsVEVL.gen.td:806)
    ve_vl_pvcvtwsrz_vvvl,                      // llvm.ve.vl.pvcvtwsrz.vvvl (IntrinsicsVEVL.gen.td:807)
    ve_vl_pveqv_vsvMvl,                        // llvm.ve.vl.pveqv.vsvMvl (IntrinsicsVEVL.gen.td:409)
    ve_vl_pveqv_vsvl,                          // llvm.ve.vl.pveqv.vsvl (IntrinsicsVEVL.gen.td:406)
    ve_vl_pveqv_vsvvl,                         // llvm.ve.vl.pveqv.vsvvl (IntrinsicsVEVL.gen.td:407)
    ve_vl_pveqv_vvvMvl,                        // llvm.ve.vl.pveqv.vvvMvl (IntrinsicsVEVL.gen.td:408)
    ve_vl_pveqv_vvvl,                          // llvm.ve.vl.pveqv.vvvl (IntrinsicsVEVL.gen.td:404)
    ve_vl_pveqv_vvvvl,                         // llvm.ve.vl.pveqv.vvvvl (IntrinsicsVEVL.gen.td:405)
    ve_vl_pvfadd_vsvMvl,                       // llvm.ve.vl.pvfadd.vsvMvl (IntrinsicsVEVL.gen.td:546)
    ve_vl_pvfadd_vsvl,                         // llvm.ve.vl.pvfadd.vsvl (IntrinsicsVEVL.gen.td:543)
    ve_vl_pvfadd_vsvvl,                        // llvm.ve.vl.pvfadd.vsvvl (IntrinsicsVEVL.gen.td:544)
    ve_vl_pvfadd_vvvMvl,                       // llvm.ve.vl.pvfadd.vvvMvl (IntrinsicsVEVL.gen.td:545)
    ve_vl_pvfadd_vvvl,                         // llvm.ve.vl.pvfadd.vvvl (IntrinsicsVEVL.gen.td:541)
    ve_vl_pvfadd_vvvvl,                        // llvm.ve.vl.pvfadd.vvvvl (IntrinsicsVEVL.gen.td:542)
    ve_vl_pvfcmp_vsvMvl,                       // llvm.ve.vl.pvfcmp.vsvMvl (IntrinsicsVEVL.gen.td:616)
    ve_vl_pvfcmp_vsvl,                         // llvm.ve.vl.pvfcmp.vsvl (IntrinsicsVEVL.gen.td:613)
    ve_vl_pvfcmp_vsvvl,                        // llvm.ve.vl.pvfcmp.vsvvl (IntrinsicsVEVL.gen.td:614)
    ve_vl_pvfcmp_vvvMvl,                       // llvm.ve.vl.pvfcmp.vvvMvl (IntrinsicsVEVL.gen.td:615)
    ve_vl_pvfcmp_vvvl,                         // llvm.ve.vl.pvfcmp.vvvl (IntrinsicsVEVL.gen.td:611)
    ve_vl_pvfcmp_vvvvl,                        // llvm.ve.vl.pvfcmp.vvvvl (IntrinsicsVEVL.gen.td:612)
    ve_vl_pvfmad_vsvvMvl,                      // llvm.ve.vl.pvfmad.vsvvMvl (IntrinsicsVEVL.gen.td:678)
    ve_vl_pvfmad_vsvvl,                        // llvm.ve.vl.pvfmad.vsvvl (IntrinsicsVEVL.gen.td:673)
    ve_vl_pvfmad_vsvvvl,                       // llvm.ve.vl.pvfmad.vsvvvl (IntrinsicsVEVL.gen.td:674)
    ve_vl_pvfmad_vvsvMvl,                      // llvm.ve.vl.pvfmad.vvsvMvl (IntrinsicsVEVL.gen.td:679)
    ve_vl_pvfmad_vvsvl,                        // llvm.ve.vl.pvfmad.vvsvl (IntrinsicsVEVL.gen.td:675)
    ve_vl_pvfmad_vvsvvl,                       // llvm.ve.vl.pvfmad.vvsvvl (IntrinsicsVEVL.gen.td:676)
    ve_vl_pvfmad_vvvvMvl,                      // llvm.ve.vl.pvfmad.vvvvMvl (IntrinsicsVEVL.gen.td:677)
    ve_vl_pvfmad_vvvvl,                        // llvm.ve.vl.pvfmad.vvvvl (IntrinsicsVEVL.gen.td:671)
    ve_vl_pvfmad_vvvvvl,                       // llvm.ve.vl.pvfmad.vvvvvl (IntrinsicsVEVL.gen.td:672)
    ve_vl_pvfmax_vsvMvl,                       // llvm.ve.vl.pvfmax.vsvMvl (IntrinsicsVEVL.gen.td:634)
    ve_vl_pvfmax_vsvl,                         // llvm.ve.vl.pvfmax.vsvl (IntrinsicsVEVL.gen.td:631)
    ve_vl_pvfmax_vsvvl,                        // llvm.ve.vl.pvfmax.vsvvl (IntrinsicsVEVL.gen.td:632)
    ve_vl_pvfmax_vvvMvl,                       // llvm.ve.vl.pvfmax.vvvMvl (IntrinsicsVEVL.gen.td:633)
    ve_vl_pvfmax_vvvl,                         // llvm.ve.vl.pvfmax.vvvl (IntrinsicsVEVL.gen.td:629)
    ve_vl_pvfmax_vvvvl,                        // llvm.ve.vl.pvfmax.vvvvl (IntrinsicsVEVL.gen.td:630)
    ve_vl_pvfmin_vsvMvl,                       // llvm.ve.vl.pvfmin.vsvMvl (IntrinsicsVEVL.gen.td:652)
    ve_vl_pvfmin_vsvl,                         // llvm.ve.vl.pvfmin.vsvl (IntrinsicsVEVL.gen.td:649)
    ve_vl_pvfmin_vsvvl,                        // llvm.ve.vl.pvfmin.vsvvl (IntrinsicsVEVL.gen.td:650)
    ve_vl_pvfmin_vvvMvl,                       // llvm.ve.vl.pvfmin.vvvMvl (IntrinsicsVEVL.gen.td:651)
    ve_vl_pvfmin_vvvl,                         // llvm.ve.vl.pvfmin.vvvl (IntrinsicsVEVL.gen.td:647)
    ve_vl_pvfmin_vvvvl,                        // llvm.ve.vl.pvfmin.vvvvl (IntrinsicsVEVL.gen.td:648)
    ve_vl_pvfmkaf_Ml,                          // llvm.ve.vl.pvfmkaf.Ml (IntrinsicsVEVL.gen.td:842)
    ve_vl_pvfmkat_Ml,                          // llvm.ve.vl.pvfmkat.Ml (IntrinsicsVEVL.gen.td:841)
    ve_vl_pvfmkseq_MvMl,                       // llvm.ve.vl.pvfmkseq.MvMl (IntrinsicsVEVL.gen.td:1102)
    ve_vl_pvfmkseq_Mvl,                        // llvm.ve.vl.pvfmkseq.Mvl (IntrinsicsVEVL.gen.td:1101)
    ve_vl_pvfmkseqnan_MvMl,                    // llvm.ve.vl.pvfmkseqnan.MvMl (IntrinsicsVEVL.gen.td:1118)
    ve_vl_pvfmkseqnan_Mvl,                     // llvm.ve.vl.pvfmkseqnan.Mvl (IntrinsicsVEVL.gen.td:1117)
    ve_vl_pvfmksge_MvMl,                       // llvm.ve.vl.pvfmksge.MvMl (IntrinsicsVEVL.gen.td:1104)
    ve_vl_pvfmksge_Mvl,                        // llvm.ve.vl.pvfmksge.Mvl (IntrinsicsVEVL.gen.td:1103)
    ve_vl_pvfmksgenan_MvMl,                    // llvm.ve.vl.pvfmksgenan.MvMl (IntrinsicsVEVL.gen.td:1120)
    ve_vl_pvfmksgenan_Mvl,                     // llvm.ve.vl.pvfmksgenan.Mvl (IntrinsicsVEVL.gen.td:1119)
    ve_vl_pvfmksgt_MvMl,                       // llvm.ve.vl.pvfmksgt.MvMl (IntrinsicsVEVL.gen.td:1096)
    ve_vl_pvfmksgt_Mvl,                        // llvm.ve.vl.pvfmksgt.Mvl (IntrinsicsVEVL.gen.td:1095)
    ve_vl_pvfmksgtnan_MvMl,                    // llvm.ve.vl.pvfmksgtnan.MvMl (IntrinsicsVEVL.gen.td:1112)
    ve_vl_pvfmksgtnan_Mvl,                     // llvm.ve.vl.pvfmksgtnan.Mvl (IntrinsicsVEVL.gen.td:1111)
    ve_vl_pvfmksle_MvMl,                       // llvm.ve.vl.pvfmksle.MvMl (IntrinsicsVEVL.gen.td:1106)
    ve_vl_pvfmksle_Mvl,                        // llvm.ve.vl.pvfmksle.Mvl (IntrinsicsVEVL.gen.td:1105)
    ve_vl_pvfmkslenan_MvMl,                    // llvm.ve.vl.pvfmkslenan.MvMl (IntrinsicsVEVL.gen.td:1122)
    ve_vl_pvfmkslenan_Mvl,                     // llvm.ve.vl.pvfmkslenan.Mvl (IntrinsicsVEVL.gen.td:1121)
    ve_vl_pvfmksloeq_mvl,                      // llvm.ve.vl.pvfmksloeq.mvl (IntrinsicsVEVL.gen.td:1051)
    ve_vl_pvfmksloeq_mvml,                     // llvm.ve.vl.pvfmksloeq.mvml (IntrinsicsVEVL.gen.td:1053)
    ve_vl_pvfmksloeqnan_mvl,                   // llvm.ve.vl.pvfmksloeqnan.mvl (IntrinsicsVEVL.gen.td:1083)
    ve_vl_pvfmksloeqnan_mvml,                  // llvm.ve.vl.pvfmksloeqnan.mvml (IntrinsicsVEVL.gen.td:1085)
    ve_vl_pvfmksloge_mvl,                      // llvm.ve.vl.pvfmksloge.mvl (IntrinsicsVEVL.gen.td:1055)
    ve_vl_pvfmksloge_mvml,                     // llvm.ve.vl.pvfmksloge.mvml (IntrinsicsVEVL.gen.td:1057)
    ve_vl_pvfmkslogenan_mvl,                   // llvm.ve.vl.pvfmkslogenan.mvl (IntrinsicsVEVL.gen.td:1087)
    ve_vl_pvfmkslogenan_mvml,                  // llvm.ve.vl.pvfmkslogenan.mvml (IntrinsicsVEVL.gen.td:1089)
    ve_vl_pvfmkslogt_mvl,                      // llvm.ve.vl.pvfmkslogt.mvl (IntrinsicsVEVL.gen.td:1039)
    ve_vl_pvfmkslogt_mvml,                     // llvm.ve.vl.pvfmkslogt.mvml (IntrinsicsVEVL.gen.td:1041)
    ve_vl_pvfmkslogtnan_mvl,                   // llvm.ve.vl.pvfmkslogtnan.mvl (IntrinsicsVEVL.gen.td:1071)
    ve_vl_pvfmkslogtnan_mvml,                  // llvm.ve.vl.pvfmkslogtnan.mvml (IntrinsicsVEVL.gen.td:1073)
    ve_vl_pvfmkslole_mvl,                      // llvm.ve.vl.pvfmkslole.mvl (IntrinsicsVEVL.gen.td:1059)
    ve_vl_pvfmkslole_mvml,                     // llvm.ve.vl.pvfmkslole.mvml (IntrinsicsVEVL.gen.td:1061)
    ve_vl_pvfmkslolenan_mvl,                   // llvm.ve.vl.pvfmkslolenan.mvl (IntrinsicsVEVL.gen.td:1091)
    ve_vl_pvfmkslolenan_mvml,                  // llvm.ve.vl.pvfmkslolenan.mvml (IntrinsicsVEVL.gen.td:1093)
    ve_vl_pvfmkslolt_mvl,                      // llvm.ve.vl.pvfmkslolt.mvl (IntrinsicsVEVL.gen.td:1043)
    ve_vl_pvfmkslolt_mvml,                     // llvm.ve.vl.pvfmkslolt.mvml (IntrinsicsVEVL.gen.td:1045)
    ve_vl_pvfmksloltnan_mvl,                   // llvm.ve.vl.pvfmksloltnan.mvl (IntrinsicsVEVL.gen.td:1075)
    ve_vl_pvfmksloltnan_mvml,                  // llvm.ve.vl.pvfmksloltnan.mvml (IntrinsicsVEVL.gen.td:1077)
    ve_vl_pvfmkslonan_mvl,                     // llvm.ve.vl.pvfmkslonan.mvl (IntrinsicsVEVL.gen.td:1067)
    ve_vl_pvfmkslonan_mvml,                    // llvm.ve.vl.pvfmkslonan.mvml (IntrinsicsVEVL.gen.td:1069)
    ve_vl_pvfmkslone_mvl,                      // llvm.ve.vl.pvfmkslone.mvl (IntrinsicsVEVL.gen.td:1047)
    ve_vl_pvfmkslone_mvml,                     // llvm.ve.vl.pvfmkslone.mvml (IntrinsicsVEVL.gen.td:1049)
    ve_vl_pvfmkslonenan_mvl,                   // llvm.ve.vl.pvfmkslonenan.mvl (IntrinsicsVEVL.gen.td:1079)
    ve_vl_pvfmkslonenan_mvml,                  // llvm.ve.vl.pvfmkslonenan.mvml (IntrinsicsVEVL.gen.td:1081)
    ve_vl_pvfmkslonum_mvl,                     // llvm.ve.vl.pvfmkslonum.mvl (IntrinsicsVEVL.gen.td:1063)
    ve_vl_pvfmkslonum_mvml,                    // llvm.ve.vl.pvfmkslonum.mvml (IntrinsicsVEVL.gen.td:1065)
    ve_vl_pvfmkslt_MvMl,                       // llvm.ve.vl.pvfmkslt.MvMl (IntrinsicsVEVL.gen.td:1098)
    ve_vl_pvfmkslt_Mvl,                        // llvm.ve.vl.pvfmkslt.Mvl (IntrinsicsVEVL.gen.td:1097)
    ve_vl_pvfmksltnan_MvMl,                    // llvm.ve.vl.pvfmksltnan.MvMl (IntrinsicsVEVL.gen.td:1114)
    ve_vl_pvfmksltnan_Mvl,                     // llvm.ve.vl.pvfmksltnan.Mvl (IntrinsicsVEVL.gen.td:1113)
    ve_vl_pvfmksnan_MvMl,                      // llvm.ve.vl.pvfmksnan.MvMl (IntrinsicsVEVL.gen.td:1110)
    ve_vl_pvfmksnan_Mvl,                       // llvm.ve.vl.pvfmksnan.Mvl (IntrinsicsVEVL.gen.td:1109)
    ve_vl_pvfmksne_MvMl,                       // llvm.ve.vl.pvfmksne.MvMl (IntrinsicsVEVL.gen.td:1100)
    ve_vl_pvfmksne_Mvl,                        // llvm.ve.vl.pvfmksne.Mvl (IntrinsicsVEVL.gen.td:1099)
    ve_vl_pvfmksnenan_MvMl,                    // llvm.ve.vl.pvfmksnenan.MvMl (IntrinsicsVEVL.gen.td:1116)
    ve_vl_pvfmksnenan_Mvl,                     // llvm.ve.vl.pvfmksnenan.Mvl (IntrinsicsVEVL.gen.td:1115)
    ve_vl_pvfmksnum_MvMl,                      // llvm.ve.vl.pvfmksnum.MvMl (IntrinsicsVEVL.gen.td:1108)
    ve_vl_pvfmksnum_Mvl,                       // llvm.ve.vl.pvfmksnum.Mvl (IntrinsicsVEVL.gen.td:1107)
    ve_vl_pvfmksupeq_mvl,                      // llvm.ve.vl.pvfmksupeq.mvl (IntrinsicsVEVL.gen.td:1052)
    ve_vl_pvfmksupeq_mvml,                     // llvm.ve.vl.pvfmksupeq.mvml (IntrinsicsVEVL.gen.td:1054)
    ve_vl_pvfmksupeqnan_mvl,                   // llvm.ve.vl.pvfmksupeqnan.mvl (IntrinsicsVEVL.gen.td:1084)
    ve_vl_pvfmksupeqnan_mvml,                  // llvm.ve.vl.pvfmksupeqnan.mvml (IntrinsicsVEVL.gen.td:1086)
    ve_vl_pvfmksupge_mvl,                      // llvm.ve.vl.pvfmksupge.mvl (IntrinsicsVEVL.gen.td:1056)
    ve_vl_pvfmksupge_mvml,                     // llvm.ve.vl.pvfmksupge.mvml (IntrinsicsVEVL.gen.td:1058)
    ve_vl_pvfmksupgenan_mvl,                   // llvm.ve.vl.pvfmksupgenan.mvl (IntrinsicsVEVL.gen.td:1088)
    ve_vl_pvfmksupgenan_mvml,                  // llvm.ve.vl.pvfmksupgenan.mvml (IntrinsicsVEVL.gen.td:1090)
    ve_vl_pvfmksupgt_mvl,                      // llvm.ve.vl.pvfmksupgt.mvl (IntrinsicsVEVL.gen.td:1040)
    ve_vl_pvfmksupgt_mvml,                     // llvm.ve.vl.pvfmksupgt.mvml (IntrinsicsVEVL.gen.td:1042)
    ve_vl_pvfmksupgtnan_mvl,                   // llvm.ve.vl.pvfmksupgtnan.mvl (IntrinsicsVEVL.gen.td:1072)
    ve_vl_pvfmksupgtnan_mvml,                  // llvm.ve.vl.pvfmksupgtnan.mvml (IntrinsicsVEVL.gen.td:1074)
    ve_vl_pvfmksuple_mvl,                      // llvm.ve.vl.pvfmksuple.mvl (IntrinsicsVEVL.gen.td:1060)
    ve_vl_pvfmksuple_mvml,                     // llvm.ve.vl.pvfmksuple.mvml (IntrinsicsVEVL.gen.td:1062)
    ve_vl_pvfmksuplenan_mvl,                   // llvm.ve.vl.pvfmksuplenan.mvl (IntrinsicsVEVL.gen.td:1092)
    ve_vl_pvfmksuplenan_mvml,                  // llvm.ve.vl.pvfmksuplenan.mvml (IntrinsicsVEVL.gen.td:1094)
    ve_vl_pvfmksuplt_mvl,                      // llvm.ve.vl.pvfmksuplt.mvl (IntrinsicsVEVL.gen.td:1044)
    ve_vl_pvfmksuplt_mvml,                     // llvm.ve.vl.pvfmksuplt.mvml (IntrinsicsVEVL.gen.td:1046)
    ve_vl_pvfmksupltnan_mvl,                   // llvm.ve.vl.pvfmksupltnan.mvl (IntrinsicsVEVL.gen.td:1076)
    ve_vl_pvfmksupltnan_mvml,                  // llvm.ve.vl.pvfmksupltnan.mvml (IntrinsicsVEVL.gen.td:1078)
    ve_vl_pvfmksupnan_mvl,                     // llvm.ve.vl.pvfmksupnan.mvl (IntrinsicsVEVL.gen.td:1068)
    ve_vl_pvfmksupnan_mvml,                    // llvm.ve.vl.pvfmksupnan.mvml (IntrinsicsVEVL.gen.td:1070)
    ve_vl_pvfmksupne_mvl,                      // llvm.ve.vl.pvfmksupne.mvl (IntrinsicsVEVL.gen.td:1048)
    ve_vl_pvfmksupne_mvml,                     // llvm.ve.vl.pvfmksupne.mvml (IntrinsicsVEVL.gen.td:1050)
    ve_vl_pvfmksupnenan_mvl,                   // llvm.ve.vl.pvfmksupnenan.mvl (IntrinsicsVEVL.gen.td:1080)
    ve_vl_pvfmksupnenan_mvml,                  // llvm.ve.vl.pvfmksupnenan.mvml (IntrinsicsVEVL.gen.td:1082)
    ve_vl_pvfmksupnum_mvl,                     // llvm.ve.vl.pvfmksupnum.mvl (IntrinsicsVEVL.gen.td:1064)
    ve_vl_pvfmksupnum_mvml,                    // llvm.ve.vl.pvfmksupnum.mvml (IntrinsicsVEVL.gen.td:1066)
    ve_vl_pvfmkweq_MvMl,                       // llvm.ve.vl.pvfmkweq.MvMl (IntrinsicsVEVL.gen.td:962)
    ve_vl_pvfmkweq_Mvl,                        // llvm.ve.vl.pvfmkweq.Mvl (IntrinsicsVEVL.gen.td:961)
    ve_vl_pvfmkweqnan_MvMl,                    // llvm.ve.vl.pvfmkweqnan.MvMl (IntrinsicsVEVL.gen.td:978)
    ve_vl_pvfmkweqnan_Mvl,                     // llvm.ve.vl.pvfmkweqnan.Mvl (IntrinsicsVEVL.gen.td:977)
    ve_vl_pvfmkwge_MvMl,                       // llvm.ve.vl.pvfmkwge.MvMl (IntrinsicsVEVL.gen.td:964)
    ve_vl_pvfmkwge_Mvl,                        // llvm.ve.vl.pvfmkwge.Mvl (IntrinsicsVEVL.gen.td:963)
    ve_vl_pvfmkwgenan_MvMl,                    // llvm.ve.vl.pvfmkwgenan.MvMl (IntrinsicsVEVL.gen.td:980)
    ve_vl_pvfmkwgenan_Mvl,                     // llvm.ve.vl.pvfmkwgenan.Mvl (IntrinsicsVEVL.gen.td:979)
    ve_vl_pvfmkwgt_MvMl,                       // llvm.ve.vl.pvfmkwgt.MvMl (IntrinsicsVEVL.gen.td:956)
    ve_vl_pvfmkwgt_Mvl,                        // llvm.ve.vl.pvfmkwgt.Mvl (IntrinsicsVEVL.gen.td:955)
    ve_vl_pvfmkwgtnan_MvMl,                    // llvm.ve.vl.pvfmkwgtnan.MvMl (IntrinsicsVEVL.gen.td:972)
    ve_vl_pvfmkwgtnan_Mvl,                     // llvm.ve.vl.pvfmkwgtnan.Mvl (IntrinsicsVEVL.gen.td:971)
    ve_vl_pvfmkwle_MvMl,                       // llvm.ve.vl.pvfmkwle.MvMl (IntrinsicsVEVL.gen.td:966)
    ve_vl_pvfmkwle_Mvl,                        // llvm.ve.vl.pvfmkwle.Mvl (IntrinsicsVEVL.gen.td:965)
    ve_vl_pvfmkwlenan_MvMl,                    // llvm.ve.vl.pvfmkwlenan.MvMl (IntrinsicsVEVL.gen.td:982)
    ve_vl_pvfmkwlenan_Mvl,                     // llvm.ve.vl.pvfmkwlenan.Mvl (IntrinsicsVEVL.gen.td:981)
    ve_vl_pvfmkwloeq_mvl,                      // llvm.ve.vl.pvfmkwloeq.mvl (IntrinsicsVEVL.gen.td:911)
    ve_vl_pvfmkwloeq_mvml,                     // llvm.ve.vl.pvfmkwloeq.mvml (IntrinsicsVEVL.gen.td:913)
    ve_vl_pvfmkwloeqnan_mvl,                   // llvm.ve.vl.pvfmkwloeqnan.mvl (IntrinsicsVEVL.gen.td:943)
    ve_vl_pvfmkwloeqnan_mvml,                  // llvm.ve.vl.pvfmkwloeqnan.mvml (IntrinsicsVEVL.gen.td:945)
    ve_vl_pvfmkwloge_mvl,                      // llvm.ve.vl.pvfmkwloge.mvl (IntrinsicsVEVL.gen.td:915)
    ve_vl_pvfmkwloge_mvml,                     // llvm.ve.vl.pvfmkwloge.mvml (IntrinsicsVEVL.gen.td:917)
    ve_vl_pvfmkwlogenan_mvl,                   // llvm.ve.vl.pvfmkwlogenan.mvl (IntrinsicsVEVL.gen.td:947)
    ve_vl_pvfmkwlogenan_mvml,                  // llvm.ve.vl.pvfmkwlogenan.mvml (IntrinsicsVEVL.gen.td:949)
    ve_vl_pvfmkwlogt_mvl,                      // llvm.ve.vl.pvfmkwlogt.mvl (IntrinsicsVEVL.gen.td:899)
    ve_vl_pvfmkwlogt_mvml,                     // llvm.ve.vl.pvfmkwlogt.mvml (IntrinsicsVEVL.gen.td:901)
    ve_vl_pvfmkwlogtnan_mvl,                   // llvm.ve.vl.pvfmkwlogtnan.mvl (IntrinsicsVEVL.gen.td:931)
    ve_vl_pvfmkwlogtnan_mvml,                  // llvm.ve.vl.pvfmkwlogtnan.mvml (IntrinsicsVEVL.gen.td:933)
    ve_vl_pvfmkwlole_mvl,                      // llvm.ve.vl.pvfmkwlole.mvl (IntrinsicsVEVL.gen.td:919)
    ve_vl_pvfmkwlole_mvml,                     // llvm.ve.vl.pvfmkwlole.mvml (IntrinsicsVEVL.gen.td:921)
    ve_vl_pvfmkwlolenan_mvl,                   // llvm.ve.vl.pvfmkwlolenan.mvl (IntrinsicsVEVL.gen.td:951)
    ve_vl_pvfmkwlolenan_mvml,                  // llvm.ve.vl.pvfmkwlolenan.mvml (IntrinsicsVEVL.gen.td:953)
    ve_vl_pvfmkwlolt_mvl,                      // llvm.ve.vl.pvfmkwlolt.mvl (IntrinsicsVEVL.gen.td:903)
    ve_vl_pvfmkwlolt_mvml,                     // llvm.ve.vl.pvfmkwlolt.mvml (IntrinsicsVEVL.gen.td:905)
    ve_vl_pvfmkwloltnan_mvl,                   // llvm.ve.vl.pvfmkwloltnan.mvl (IntrinsicsVEVL.gen.td:935)
    ve_vl_pvfmkwloltnan_mvml,                  // llvm.ve.vl.pvfmkwloltnan.mvml (IntrinsicsVEVL.gen.td:937)
    ve_vl_pvfmkwlonan_mvl,                     // llvm.ve.vl.pvfmkwlonan.mvl (IntrinsicsVEVL.gen.td:927)
    ve_vl_pvfmkwlonan_mvml,                    // llvm.ve.vl.pvfmkwlonan.mvml (IntrinsicsVEVL.gen.td:929)
    ve_vl_pvfmkwlone_mvl,                      // llvm.ve.vl.pvfmkwlone.mvl (IntrinsicsVEVL.gen.td:907)
    ve_vl_pvfmkwlone_mvml,                     // llvm.ve.vl.pvfmkwlone.mvml (IntrinsicsVEVL.gen.td:909)
    ve_vl_pvfmkwlonenan_mvl,                   // llvm.ve.vl.pvfmkwlonenan.mvl (IntrinsicsVEVL.gen.td:939)
    ve_vl_pvfmkwlonenan_mvml,                  // llvm.ve.vl.pvfmkwlonenan.mvml (IntrinsicsVEVL.gen.td:941)
    ve_vl_pvfmkwlonum_mvl,                     // llvm.ve.vl.pvfmkwlonum.mvl (IntrinsicsVEVL.gen.td:923)
    ve_vl_pvfmkwlonum_mvml,                    // llvm.ve.vl.pvfmkwlonum.mvml (IntrinsicsVEVL.gen.td:925)
    ve_vl_pvfmkwlt_MvMl,                       // llvm.ve.vl.pvfmkwlt.MvMl (IntrinsicsVEVL.gen.td:958)
    ve_vl_pvfmkwlt_Mvl,                        // llvm.ve.vl.pvfmkwlt.Mvl (IntrinsicsVEVL.gen.td:957)
    ve_vl_pvfmkwltnan_MvMl,                    // llvm.ve.vl.pvfmkwltnan.MvMl (IntrinsicsVEVL.gen.td:974)
    ve_vl_pvfmkwltnan_Mvl,                     // llvm.ve.vl.pvfmkwltnan.Mvl (IntrinsicsVEVL.gen.td:973)
    ve_vl_pvfmkwnan_MvMl,                      // llvm.ve.vl.pvfmkwnan.MvMl (IntrinsicsVEVL.gen.td:970)
    ve_vl_pvfmkwnan_Mvl,                       // llvm.ve.vl.pvfmkwnan.Mvl (IntrinsicsVEVL.gen.td:969)
    ve_vl_pvfmkwne_MvMl,                       // llvm.ve.vl.pvfmkwne.MvMl (IntrinsicsVEVL.gen.td:960)
    ve_vl_pvfmkwne_Mvl,                        // llvm.ve.vl.pvfmkwne.Mvl (IntrinsicsVEVL.gen.td:959)
    ve_vl_pvfmkwnenan_MvMl,                    // llvm.ve.vl.pvfmkwnenan.MvMl (IntrinsicsVEVL.gen.td:976)
    ve_vl_pvfmkwnenan_Mvl,                     // llvm.ve.vl.pvfmkwnenan.Mvl (IntrinsicsVEVL.gen.td:975)
    ve_vl_pvfmkwnum_MvMl,                      // llvm.ve.vl.pvfmkwnum.MvMl (IntrinsicsVEVL.gen.td:968)
    ve_vl_pvfmkwnum_Mvl,                       // llvm.ve.vl.pvfmkwnum.Mvl (IntrinsicsVEVL.gen.td:967)
    ve_vl_pvfmkwupeq_mvl,                      // llvm.ve.vl.pvfmkwupeq.mvl (IntrinsicsVEVL.gen.td:912)
    ve_vl_pvfmkwupeq_mvml,                     // llvm.ve.vl.pvfmkwupeq.mvml (IntrinsicsVEVL.gen.td:914)
    ve_vl_pvfmkwupeqnan_mvl,                   // llvm.ve.vl.pvfmkwupeqnan.mvl (IntrinsicsVEVL.gen.td:944)
    ve_vl_pvfmkwupeqnan_mvml,                  // llvm.ve.vl.pvfmkwupeqnan.mvml (IntrinsicsVEVL.gen.td:946)
    ve_vl_pvfmkwupge_mvl,                      // llvm.ve.vl.pvfmkwupge.mvl (IntrinsicsVEVL.gen.td:916)
    ve_vl_pvfmkwupge_mvml,                     // llvm.ve.vl.pvfmkwupge.mvml (IntrinsicsVEVL.gen.td:918)
    ve_vl_pvfmkwupgenan_mvl,                   // llvm.ve.vl.pvfmkwupgenan.mvl (IntrinsicsVEVL.gen.td:948)
    ve_vl_pvfmkwupgenan_mvml,                  // llvm.ve.vl.pvfmkwupgenan.mvml (IntrinsicsVEVL.gen.td:950)
    ve_vl_pvfmkwupgt_mvl,                      // llvm.ve.vl.pvfmkwupgt.mvl (IntrinsicsVEVL.gen.td:900)
    ve_vl_pvfmkwupgt_mvml,                     // llvm.ve.vl.pvfmkwupgt.mvml (IntrinsicsVEVL.gen.td:902)
    ve_vl_pvfmkwupgtnan_mvl,                   // llvm.ve.vl.pvfmkwupgtnan.mvl (IntrinsicsVEVL.gen.td:932)
    ve_vl_pvfmkwupgtnan_mvml,                  // llvm.ve.vl.pvfmkwupgtnan.mvml (IntrinsicsVEVL.gen.td:934)
    ve_vl_pvfmkwuple_mvl,                      // llvm.ve.vl.pvfmkwuple.mvl (IntrinsicsVEVL.gen.td:920)
    ve_vl_pvfmkwuple_mvml,                     // llvm.ve.vl.pvfmkwuple.mvml (IntrinsicsVEVL.gen.td:922)
    ve_vl_pvfmkwuplenan_mvl,                   // llvm.ve.vl.pvfmkwuplenan.mvl (IntrinsicsVEVL.gen.td:952)
    ve_vl_pvfmkwuplenan_mvml,                  // llvm.ve.vl.pvfmkwuplenan.mvml (IntrinsicsVEVL.gen.td:954)
    ve_vl_pvfmkwuplt_mvl,                      // llvm.ve.vl.pvfmkwuplt.mvl (IntrinsicsVEVL.gen.td:904)
    ve_vl_pvfmkwuplt_mvml,                     // llvm.ve.vl.pvfmkwuplt.mvml (IntrinsicsVEVL.gen.td:906)
    ve_vl_pvfmkwupltnan_mvl,                   // llvm.ve.vl.pvfmkwupltnan.mvl (IntrinsicsVEVL.gen.td:936)
    ve_vl_pvfmkwupltnan_mvml,                  // llvm.ve.vl.pvfmkwupltnan.mvml (IntrinsicsVEVL.gen.td:938)
    ve_vl_pvfmkwupnan_mvl,                     // llvm.ve.vl.pvfmkwupnan.mvl (IntrinsicsVEVL.gen.td:928)
    ve_vl_pvfmkwupnan_mvml,                    // llvm.ve.vl.pvfmkwupnan.mvml (IntrinsicsVEVL.gen.td:930)
    ve_vl_pvfmkwupne_mvl,                      // llvm.ve.vl.pvfmkwupne.mvl (IntrinsicsVEVL.gen.td:908)
    ve_vl_pvfmkwupne_mvml,                     // llvm.ve.vl.pvfmkwupne.mvml (IntrinsicsVEVL.gen.td:910)
    ve_vl_pvfmkwupnenan_mvl,                   // llvm.ve.vl.pvfmkwupnenan.mvl (IntrinsicsVEVL.gen.td:940)
    ve_vl_pvfmkwupnenan_mvml,                  // llvm.ve.vl.pvfmkwupnenan.mvml (IntrinsicsVEVL.gen.td:942)
    ve_vl_pvfmkwupnum_mvl,                     // llvm.ve.vl.pvfmkwupnum.mvl (IntrinsicsVEVL.gen.td:924)
    ve_vl_pvfmkwupnum_mvml,                    // llvm.ve.vl.pvfmkwupnum.mvml (IntrinsicsVEVL.gen.td:926)
    ve_vl_pvfmsb_vsvvMvl,                      // llvm.ve.vl.pvfmsb.vsvvMvl (IntrinsicsVEVL.gen.td:705)
    ve_vl_pvfmsb_vsvvl,                        // llvm.ve.vl.pvfmsb.vsvvl (IntrinsicsVEVL.gen.td:700)
    ve_vl_pvfmsb_vsvvvl,                       // llvm.ve.vl.pvfmsb.vsvvvl (IntrinsicsVEVL.gen.td:701)
    ve_vl_pvfmsb_vvsvMvl,                      // llvm.ve.vl.pvfmsb.vvsvMvl (IntrinsicsVEVL.gen.td:706)
    ve_vl_pvfmsb_vvsvl,                        // llvm.ve.vl.pvfmsb.vvsvl (IntrinsicsVEVL.gen.td:702)
    ve_vl_pvfmsb_vvsvvl,                       // llvm.ve.vl.pvfmsb.vvsvvl (IntrinsicsVEVL.gen.td:703)
    ve_vl_pvfmsb_vvvvMvl,                      // llvm.ve.vl.pvfmsb.vvvvMvl (IntrinsicsVEVL.gen.td:704)
    ve_vl_pvfmsb_vvvvl,                        // llvm.ve.vl.pvfmsb.vvvvl (IntrinsicsVEVL.gen.td:698)
    ve_vl_pvfmsb_vvvvvl,                       // llvm.ve.vl.pvfmsb.vvvvvl (IntrinsicsVEVL.gen.td:699)
    ve_vl_pvfmul_vsvMvl,                       // llvm.ve.vl.pvfmul.vsvMvl (IntrinsicsVEVL.gen.td:582)
    ve_vl_pvfmul_vsvl,                         // llvm.ve.vl.pvfmul.vsvl (IntrinsicsVEVL.gen.td:579)
    ve_vl_pvfmul_vsvvl,                        // llvm.ve.vl.pvfmul.vsvvl (IntrinsicsVEVL.gen.td:580)
    ve_vl_pvfmul_vvvMvl,                       // llvm.ve.vl.pvfmul.vvvMvl (IntrinsicsVEVL.gen.td:581)
    ve_vl_pvfmul_vvvl,                         // llvm.ve.vl.pvfmul.vvvl (IntrinsicsVEVL.gen.td:577)
    ve_vl_pvfmul_vvvvl,                        // llvm.ve.vl.pvfmul.vvvvl (IntrinsicsVEVL.gen.td:578)
    ve_vl_pvfnmad_vsvvMvl,                     // llvm.ve.vl.pvfnmad.vsvvMvl (IntrinsicsVEVL.gen.td:732)
    ve_vl_pvfnmad_vsvvl,                       // llvm.ve.vl.pvfnmad.vsvvl (IntrinsicsVEVL.gen.td:727)
    ve_vl_pvfnmad_vsvvvl,                      // llvm.ve.vl.pvfnmad.vsvvvl (IntrinsicsVEVL.gen.td:728)
    ve_vl_pvfnmad_vvsvMvl,                     // llvm.ve.vl.pvfnmad.vvsvMvl (IntrinsicsVEVL.gen.td:733)
    ve_vl_pvfnmad_vvsvl,                       // llvm.ve.vl.pvfnmad.vvsvl (IntrinsicsVEVL.gen.td:729)
    ve_vl_pvfnmad_vvsvvl,                      // llvm.ve.vl.pvfnmad.vvsvvl (IntrinsicsVEVL.gen.td:730)
    ve_vl_pvfnmad_vvvvMvl,                     // llvm.ve.vl.pvfnmad.vvvvMvl (IntrinsicsVEVL.gen.td:731)
    ve_vl_pvfnmad_vvvvl,                       // llvm.ve.vl.pvfnmad.vvvvl (IntrinsicsVEVL.gen.td:725)
    ve_vl_pvfnmad_vvvvvl,                      // llvm.ve.vl.pvfnmad.vvvvvl (IntrinsicsVEVL.gen.td:726)
    ve_vl_pvfnmsb_vsvvMvl,                     // llvm.ve.vl.pvfnmsb.vsvvMvl (IntrinsicsVEVL.gen.td:759)
    ve_vl_pvfnmsb_vsvvl,                       // llvm.ve.vl.pvfnmsb.vsvvl (IntrinsicsVEVL.gen.td:754)
    ve_vl_pvfnmsb_vsvvvl,                      // llvm.ve.vl.pvfnmsb.vsvvvl (IntrinsicsVEVL.gen.td:755)
    ve_vl_pvfnmsb_vvsvMvl,                     // llvm.ve.vl.pvfnmsb.vvsvMvl (IntrinsicsVEVL.gen.td:760)
    ve_vl_pvfnmsb_vvsvl,                       // llvm.ve.vl.pvfnmsb.vvsvl (IntrinsicsVEVL.gen.td:756)
    ve_vl_pvfnmsb_vvsvvl,                      // llvm.ve.vl.pvfnmsb.vvsvvl (IntrinsicsVEVL.gen.td:757)
    ve_vl_pvfnmsb_vvvvMvl,                     // llvm.ve.vl.pvfnmsb.vvvvMvl (IntrinsicsVEVL.gen.td:758)
    ve_vl_pvfnmsb_vvvvl,                       // llvm.ve.vl.pvfnmsb.vvvvl (IntrinsicsVEVL.gen.td:752)
    ve_vl_pvfnmsb_vvvvvl,                      // llvm.ve.vl.pvfnmsb.vvvvvl (IntrinsicsVEVL.gen.td:753)
    ve_vl_pvfsub_vsvMvl,                       // llvm.ve.vl.pvfsub.vsvMvl (IntrinsicsVEVL.gen.td:564)
    ve_vl_pvfsub_vsvl,                         // llvm.ve.vl.pvfsub.vsvl (IntrinsicsVEVL.gen.td:561)
    ve_vl_pvfsub_vsvvl,                        // llvm.ve.vl.pvfsub.vsvvl (IntrinsicsVEVL.gen.td:562)
    ve_vl_pvfsub_vvvMvl,                       // llvm.ve.vl.pvfsub.vvvMvl (IntrinsicsVEVL.gen.td:563)
    ve_vl_pvfsub_vvvl,                         // llvm.ve.vl.pvfsub.vvvl (IntrinsicsVEVL.gen.td:559)
    ve_vl_pvfsub_vvvvl,                        // llvm.ve.vl.pvfsub.vvvvl (IntrinsicsVEVL.gen.td:560)
    ve_vl_pvldz_vvMvl,                         // llvm.ve.vl.pvldz.vvMvl (IntrinsicsVEVL.gen.td:421)
    ve_vl_pvldz_vvl,                           // llvm.ve.vl.pvldz.vvl (IntrinsicsVEVL.gen.td:419)
    ve_vl_pvldz_vvvl,                          // llvm.ve.vl.pvldz.vvvl (IntrinsicsVEVL.gen.td:420)
    ve_vl_pvldzlo_vvl,                         // llvm.ve.vl.pvldzlo.vvl (IntrinsicsVEVL.gen.td:413)
    ve_vl_pvldzlo_vvmvl,                       // llvm.ve.vl.pvldzlo.vvmvl (IntrinsicsVEVL.gen.td:415)
    ve_vl_pvldzlo_vvvl,                        // llvm.ve.vl.pvldzlo.vvvl (IntrinsicsVEVL.gen.td:414)
    ve_vl_pvldzup_vvl,                         // llvm.ve.vl.pvldzup.vvl (IntrinsicsVEVL.gen.td:416)
    ve_vl_pvldzup_vvmvl,                       // llvm.ve.vl.pvldzup.vvmvl (IntrinsicsVEVL.gen.td:418)
    ve_vl_pvldzup_vvvl,                        // llvm.ve.vl.pvldzup.vvvl (IntrinsicsVEVL.gen.td:417)
    ve_vl_pvmaxs_vsvMvl,                       // llvm.ve.vl.pvmaxs.vsvMvl (IntrinsicsVEVL.gen.td:331)
    ve_vl_pvmaxs_vsvl,                         // llvm.ve.vl.pvmaxs.vsvl (IntrinsicsVEVL.gen.td:328)
    ve_vl_pvmaxs_vsvvl,                        // llvm.ve.vl.pvmaxs.vsvvl (IntrinsicsVEVL.gen.td:329)
    ve_vl_pvmaxs_vvvMvl,                       // llvm.ve.vl.pvmaxs.vvvMvl (IntrinsicsVEVL.gen.td:330)
    ve_vl_pvmaxs_vvvl,                         // llvm.ve.vl.pvmaxs.vvvl (IntrinsicsVEVL.gen.td:326)
    ve_vl_pvmaxs_vvvvl,                        // llvm.ve.vl.pvmaxs.vvvvl (IntrinsicsVEVL.gen.td:327)
    ve_vl_pvmins_vsvMvl,                       // llvm.ve.vl.pvmins.vsvMvl (IntrinsicsVEVL.gen.td:349)
    ve_vl_pvmins_vsvl,                         // llvm.ve.vl.pvmins.vsvl (IntrinsicsVEVL.gen.td:346)
    ve_vl_pvmins_vsvvl,                        // llvm.ve.vl.pvmins.vsvvl (IntrinsicsVEVL.gen.td:347)
    ve_vl_pvmins_vvvMvl,                       // llvm.ve.vl.pvmins.vvvMvl (IntrinsicsVEVL.gen.td:348)
    ve_vl_pvmins_vvvl,                         // llvm.ve.vl.pvmins.vvvl (IntrinsicsVEVL.gen.td:344)
    ve_vl_pvmins_vvvvl,                        // llvm.ve.vl.pvmins.vvvvl (IntrinsicsVEVL.gen.td:345)
    ve_vl_pvor_vsvMvl,                         // llvm.ve.vl.pvor.vsvMvl (IntrinsicsVEVL.gen.td:385)
    ve_vl_pvor_vsvl,                           // llvm.ve.vl.pvor.vsvl (IntrinsicsVEVL.gen.td:382)
    ve_vl_pvor_vsvvl,                          // llvm.ve.vl.pvor.vsvvl (IntrinsicsVEVL.gen.td:383)
    ve_vl_pvor_vvvMvl,                         // llvm.ve.vl.pvor.vvvMvl (IntrinsicsVEVL.gen.td:384)
    ve_vl_pvor_vvvl,                           // llvm.ve.vl.pvor.vvvl (IntrinsicsVEVL.gen.td:380)
    ve_vl_pvor_vvvvl,                          // llvm.ve.vl.pvor.vvvvl (IntrinsicsVEVL.gen.td:381)
    ve_vl_pvpcnt_vvMvl,                        // llvm.ve.vl.pvpcnt.vvMvl (IntrinsicsVEVL.gen.td:433)
    ve_vl_pvpcnt_vvl,                          // llvm.ve.vl.pvpcnt.vvl (IntrinsicsVEVL.gen.td:431)
    ve_vl_pvpcnt_vvvl,                         // llvm.ve.vl.pvpcnt.vvvl (IntrinsicsVEVL.gen.td:432)
    ve_vl_pvpcntlo_vvl,                        // llvm.ve.vl.pvpcntlo.vvl (IntrinsicsVEVL.gen.td:425)
    ve_vl_pvpcntlo_vvmvl,                      // llvm.ve.vl.pvpcntlo.vvmvl (IntrinsicsVEVL.gen.td:427)
    ve_vl_pvpcntlo_vvvl,                       // llvm.ve.vl.pvpcntlo.vvvl (IntrinsicsVEVL.gen.td:426)
    ve_vl_pvpcntup_vvl,                        // llvm.ve.vl.pvpcntup.vvl (IntrinsicsVEVL.gen.td:428)
    ve_vl_pvpcntup_vvmvl,                      // llvm.ve.vl.pvpcntup.vvmvl (IntrinsicsVEVL.gen.td:430)
    ve_vl_pvpcntup_vvvl,                       // llvm.ve.vl.pvpcntup.vvvl (IntrinsicsVEVL.gen.td:429)
    ve_vl_pvrcp_vvl,                           // llvm.ve.vl.pvrcp.vvl (IntrinsicsVEVL.gen.td:765)
    ve_vl_pvrcp_vvvl,                          // llvm.ve.vl.pvrcp.vvvl (IntrinsicsVEVL.gen.td:766)
    ve_vl_pvrsqrt_vvl,                         // llvm.ve.vl.pvrsqrt.vvl (IntrinsicsVEVL.gen.td:771)
    ve_vl_pvrsqrt_vvvl,                        // llvm.ve.vl.pvrsqrt.vvvl (IntrinsicsVEVL.gen.td:772)
    ve_vl_pvrsqrtnex_vvl,                      // llvm.ve.vl.pvrsqrtnex.vvl (IntrinsicsVEVL.gen.td:777)
    ve_vl_pvrsqrtnex_vvvl,                     // llvm.ve.vl.pvrsqrtnex.vvvl (IntrinsicsVEVL.gen.td:778)
    ve_vl_pvseq_vl,                            // llvm.ve.vl.pvseq.vl (IntrinsicsVEVL.gen.td:452)
    ve_vl_pvseq_vvl,                           // llvm.ve.vl.pvseq.vvl (IntrinsicsVEVL.gen.td:453)
    ve_vl_pvseqlo_vl,                          // llvm.ve.vl.pvseqlo.vl (IntrinsicsVEVL.gen.td:448)
    ve_vl_pvseqlo_vvl,                         // llvm.ve.vl.pvseqlo.vvl (IntrinsicsVEVL.gen.td:449)
    ve_vl_pvsequp_vl,                          // llvm.ve.vl.pvsequp.vl (IntrinsicsVEVL.gen.td:450)
    ve_vl_pvsequp_vvl,                         // llvm.ve.vl.pvsequp.vvl (IntrinsicsVEVL.gen.td:451)
    ve_vl_pvsla_vvsMvl,                        // llvm.ve.vl.pvsla.vvsMvl (IntrinsicsVEVL.gen.td:495)
    ve_vl_pvsla_vvsl,                          // llvm.ve.vl.pvsla.vvsl (IntrinsicsVEVL.gen.td:492)
    ve_vl_pvsla_vvsvl,                         // llvm.ve.vl.pvsla.vvsvl (IntrinsicsVEVL.gen.td:493)
    ve_vl_pvsla_vvvMvl,                        // llvm.ve.vl.pvsla.vvvMvl (IntrinsicsVEVL.gen.td:494)
    ve_vl_pvsla_vvvl,                          // llvm.ve.vl.pvsla.vvvl (IntrinsicsVEVL.gen.td:490)
    ve_vl_pvsla_vvvvl,                         // llvm.ve.vl.pvsla.vvvvl (IntrinsicsVEVL.gen.td:491)
    ve_vl_pvsll_vvsMvl,                        // llvm.ve.vl.pvsll.vvsMvl (IntrinsicsVEVL.gen.td:465)
    ve_vl_pvsll_vvsl,                          // llvm.ve.vl.pvsll.vvsl (IntrinsicsVEVL.gen.td:462)
    ve_vl_pvsll_vvsvl,                         // llvm.ve.vl.pvsll.vvsvl (IntrinsicsVEVL.gen.td:463)
    ve_vl_pvsll_vvvMvl,                        // llvm.ve.vl.pvsll.vvvMvl (IntrinsicsVEVL.gen.td:464)
    ve_vl_pvsll_vvvl,                          // llvm.ve.vl.pvsll.vvvl (IntrinsicsVEVL.gen.td:460)
    ve_vl_pvsll_vvvvl,                         // llvm.ve.vl.pvsll.vvvvl (IntrinsicsVEVL.gen.td:461)
    ve_vl_pvsra_vvsMvl,                        // llvm.ve.vl.pvsra.vvsMvl (IntrinsicsVEVL.gen.td:519)
    ve_vl_pvsra_vvsl,                          // llvm.ve.vl.pvsra.vvsl (IntrinsicsVEVL.gen.td:516)
    ve_vl_pvsra_vvsvl,                         // llvm.ve.vl.pvsra.vvsvl (IntrinsicsVEVL.gen.td:517)
    ve_vl_pvsra_vvvMvl,                        // llvm.ve.vl.pvsra.vvvMvl (IntrinsicsVEVL.gen.td:518)
    ve_vl_pvsra_vvvl,                          // llvm.ve.vl.pvsra.vvvl (IntrinsicsVEVL.gen.td:514)
    ve_vl_pvsra_vvvvl,                         // llvm.ve.vl.pvsra.vvvvl (IntrinsicsVEVL.gen.td:515)
    ve_vl_pvsrl_vvsMvl,                        // llvm.ve.vl.pvsrl.vvsMvl (IntrinsicsVEVL.gen.td:477)
    ve_vl_pvsrl_vvsl,                          // llvm.ve.vl.pvsrl.vvsl (IntrinsicsVEVL.gen.td:474)
    ve_vl_pvsrl_vvsvl,                         // llvm.ve.vl.pvsrl.vvsvl (IntrinsicsVEVL.gen.td:475)
    ve_vl_pvsrl_vvvMvl,                        // llvm.ve.vl.pvsrl.vvvMvl (IntrinsicsVEVL.gen.td:476)
    ve_vl_pvsrl_vvvl,                          // llvm.ve.vl.pvsrl.vvvl (IntrinsicsVEVL.gen.td:472)
    ve_vl_pvsrl_vvvvl,                         // llvm.ve.vl.pvsrl.vvvvl (IntrinsicsVEVL.gen.td:473)
    ve_vl_pvsubs_vsvMvl,                       // llvm.ve.vl.pvsubs.vsvMvl (IntrinsicsVEVL.gen.td:186)
    ve_vl_pvsubs_vsvl,                         // llvm.ve.vl.pvsubs.vsvl (IntrinsicsVEVL.gen.td:183)
    ve_vl_pvsubs_vsvvl,                        // llvm.ve.vl.pvsubs.vsvvl (IntrinsicsVEVL.gen.td:184)
    ve_vl_pvsubs_vvvMvl,                       // llvm.ve.vl.pvsubs.vvvMvl (IntrinsicsVEVL.gen.td:185)
    ve_vl_pvsubs_vvvl,                         // llvm.ve.vl.pvsubs.vvvl (IntrinsicsVEVL.gen.td:181)
    ve_vl_pvsubs_vvvvl,                        // llvm.ve.vl.pvsubs.vvvvl (IntrinsicsVEVL.gen.td:182)
    ve_vl_pvsubu_vsvMvl,                       // llvm.ve.vl.pvsubu.vsvMvl (IntrinsicsVEVL.gen.td:168)
    ve_vl_pvsubu_vsvl,                         // llvm.ve.vl.pvsubu.vsvl (IntrinsicsVEVL.gen.td:165)
    ve_vl_pvsubu_vsvvl,                        // llvm.ve.vl.pvsubu.vsvvl (IntrinsicsVEVL.gen.td:166)
    ve_vl_pvsubu_vvvMvl,                       // llvm.ve.vl.pvsubu.vvvMvl (IntrinsicsVEVL.gen.td:167)
    ve_vl_pvsubu_vvvl,                         // llvm.ve.vl.pvsubu.vvvl (IntrinsicsVEVL.gen.td:163)
    ve_vl_pvsubu_vvvvl,                        // llvm.ve.vl.pvsubu.vvvvl (IntrinsicsVEVL.gen.td:164)
    ve_vl_pvxor_vsvMvl,                        // llvm.ve.vl.pvxor.vsvMvl (IntrinsicsVEVL.gen.td:397)
    ve_vl_pvxor_vsvl,                          // llvm.ve.vl.pvxor.vsvl (IntrinsicsVEVL.gen.td:394)
    ve_vl_pvxor_vsvvl,                         // llvm.ve.vl.pvxor.vsvvl (IntrinsicsVEVL.gen.td:395)
    ve_vl_pvxor_vvvMvl,                        // llvm.ve.vl.pvxor.vvvMvl (IntrinsicsVEVL.gen.td:396)
    ve_vl_pvxor_vvvl,                          // llvm.ve.vl.pvxor.vvvl (IntrinsicsVEVL.gen.td:392)
    ve_vl_pvxor_vvvvl,                         // llvm.ve.vl.pvxor.vvvvl (IntrinsicsVEVL.gen.td:393)
    ve_vl_scr_sss,                             // llvm.ve.vl.scr.sss (IntrinsicsVEVL.gen.td:1251)
    ve_vl_svm_sMs,                             // llvm.ve.vl.svm.sMs (IntrinsicsVEVL.gen.td:90)
    ve_vl_svm_sms,                             // llvm.ve.vl.svm.sms (IntrinsicsVEVL.gen.td:89)
    ve_vl_svob,                                // llvm.ve.vl.svob (IntrinsicsVEVL.gen.td:1257)
    ve_vl_tovm_sml,                            // llvm.ve.vl.tovm.sml (IntrinsicsVEVL.gen.td:1249)
    ve_vl_tscr_ssss,                           // llvm.ve.vl.tscr.ssss (IntrinsicsVEVL.gen.td:1252)
    ve_vl_vaddsl_vsvl,                         // llvm.ve.vl.vaddsl.vsvl (IntrinsicsVEVL.gen.td:147)
    ve_vl_vaddsl_vsvmvl,                       // llvm.ve.vl.vaddsl.vsvmvl (IntrinsicsVEVL.gen.td:150)
    ve_vl_vaddsl_vsvvl,                        // llvm.ve.vl.vaddsl.vsvvl (IntrinsicsVEVL.gen.td:148)
    ve_vl_vaddsl_vvvl,                         // llvm.ve.vl.vaddsl.vvvl (IntrinsicsVEVL.gen.td:145)
    ve_vl_vaddsl_vvvmvl,                       // llvm.ve.vl.vaddsl.vvvmvl (IntrinsicsVEVL.gen.td:149)
    ve_vl_vaddsl_vvvvl,                        // llvm.ve.vl.vaddsl.vvvvl (IntrinsicsVEVL.gen.td:146)
    ve_vl_vaddswsx_vsvl,                       // llvm.ve.vl.vaddswsx.vsvl (IntrinsicsVEVL.gen.td:129)
    ve_vl_vaddswsx_vsvmvl,                     // llvm.ve.vl.vaddswsx.vsvmvl (IntrinsicsVEVL.gen.td:132)
    ve_vl_vaddswsx_vsvvl,                      // llvm.ve.vl.vaddswsx.vsvvl (IntrinsicsVEVL.gen.td:130)
    ve_vl_vaddswsx_vvvl,                       // llvm.ve.vl.vaddswsx.vvvl (IntrinsicsVEVL.gen.td:127)
    ve_vl_vaddswsx_vvvmvl,                     // llvm.ve.vl.vaddswsx.vvvmvl (IntrinsicsVEVL.gen.td:131)
    ve_vl_vaddswsx_vvvvl,                      // llvm.ve.vl.vaddswsx.vvvvl (IntrinsicsVEVL.gen.td:128)
    ve_vl_vaddswzx_vsvl,                       // llvm.ve.vl.vaddswzx.vsvl (IntrinsicsVEVL.gen.td:135)
    ve_vl_vaddswzx_vsvmvl,                     // llvm.ve.vl.vaddswzx.vsvmvl (IntrinsicsVEVL.gen.td:138)
    ve_vl_vaddswzx_vsvvl,                      // llvm.ve.vl.vaddswzx.vsvvl (IntrinsicsVEVL.gen.td:136)
    ve_vl_vaddswzx_vvvl,                       // llvm.ve.vl.vaddswzx.vvvl (IntrinsicsVEVL.gen.td:133)
    ve_vl_vaddswzx_vvvmvl,                     // llvm.ve.vl.vaddswzx.vvvmvl (IntrinsicsVEVL.gen.td:137)
    ve_vl_vaddswzx_vvvvl,                      // llvm.ve.vl.vaddswzx.vvvvl (IntrinsicsVEVL.gen.td:134)
    ve_vl_vaddul_vsvl,                         // llvm.ve.vl.vaddul.vsvl (IntrinsicsVEVL.gen.td:111)
    ve_vl_vaddul_vsvmvl,                       // llvm.ve.vl.vaddul.vsvmvl (IntrinsicsVEVL.gen.td:114)
    ve_vl_vaddul_vsvvl,                        // llvm.ve.vl.vaddul.vsvvl (IntrinsicsVEVL.gen.td:112)
    ve_vl_vaddul_vvvl,                         // llvm.ve.vl.vaddul.vvvl (IntrinsicsVEVL.gen.td:109)
    ve_vl_vaddul_vvvmvl,                       // llvm.ve.vl.vaddul.vvvmvl (IntrinsicsVEVL.gen.td:113)
    ve_vl_vaddul_vvvvl,                        // llvm.ve.vl.vaddul.vvvvl (IntrinsicsVEVL.gen.td:110)
    ve_vl_vadduw_vsvl,                         // llvm.ve.vl.vadduw.vsvl (IntrinsicsVEVL.gen.td:117)
    ve_vl_vadduw_vsvmvl,                       // llvm.ve.vl.vadduw.vsvmvl (IntrinsicsVEVL.gen.td:120)
    ve_vl_vadduw_vsvvl,                        // llvm.ve.vl.vadduw.vsvvl (IntrinsicsVEVL.gen.td:118)
    ve_vl_vadduw_vvvl,                         // llvm.ve.vl.vadduw.vvvl (IntrinsicsVEVL.gen.td:115)
    ve_vl_vadduw_vvvmvl,                       // llvm.ve.vl.vadduw.vvvmvl (IntrinsicsVEVL.gen.td:119)
    ve_vl_vadduw_vvvvl,                        // llvm.ve.vl.vadduw.vvvvl (IntrinsicsVEVL.gen.td:116)
    ve_vl_vand_vsvl,                           // llvm.ve.vl.vand.vsvl (IntrinsicsVEVL.gen.td:364)
    ve_vl_vand_vsvmvl,                         // llvm.ve.vl.vand.vsvmvl (IntrinsicsVEVL.gen.td:367)
    ve_vl_vand_vsvvl,                          // llvm.ve.vl.vand.vsvvl (IntrinsicsVEVL.gen.td:365)
    ve_vl_vand_vvvl,                           // llvm.ve.vl.vand.vvvl (IntrinsicsVEVL.gen.td:362)
    ve_vl_vand_vvvmvl,                         // llvm.ve.vl.vand.vvvmvl (IntrinsicsVEVL.gen.td:366)
    ve_vl_vand_vvvvl,                          // llvm.ve.vl.vand.vvvvl (IntrinsicsVEVL.gen.td:363)
    ve_vl_vbrdd_vsl,                           // llvm.ve.vl.vbrdd.vsl (IntrinsicsVEVL.gen.td:91)
    ve_vl_vbrdd_vsmvl,                         // llvm.ve.vl.vbrdd.vsmvl (IntrinsicsVEVL.gen.td:93)
    ve_vl_vbrdd_vsvl,                          // llvm.ve.vl.vbrdd.vsvl (IntrinsicsVEVL.gen.td:92)
    ve_vl_vbrdl_vsl,                           // llvm.ve.vl.vbrdl.vsl (IntrinsicsVEVL.gen.td:94)
    ve_vl_vbrdl_vsmvl,                         // llvm.ve.vl.vbrdl.vsmvl (IntrinsicsVEVL.gen.td:96)
    ve_vl_vbrdl_vsvl,                          // llvm.ve.vl.vbrdl.vsvl (IntrinsicsVEVL.gen.td:95)
    ve_vl_vbrds_vsl,                           // llvm.ve.vl.vbrds.vsl (IntrinsicsVEVL.gen.td:97)
    ve_vl_vbrds_vsmvl,                         // llvm.ve.vl.vbrds.vsmvl (IntrinsicsVEVL.gen.td:99)
    ve_vl_vbrds_vsvl,                          // llvm.ve.vl.vbrds.vsvl (IntrinsicsVEVL.gen.td:98)
    ve_vl_vbrdw_vsl,                           // llvm.ve.vl.vbrdw.vsl (IntrinsicsVEVL.gen.td:100)
    ve_vl_vbrdw_vsmvl,                         // llvm.ve.vl.vbrdw.vsmvl (IntrinsicsVEVL.gen.td:102)
    ve_vl_vbrdw_vsvl,                          // llvm.ve.vl.vbrdw.vsvl (IntrinsicsVEVL.gen.td:101)
    ve_vl_vbrv_vvl,                            // llvm.ve.vl.vbrv.vvl (IntrinsicsVEVL.gen.td:434)
    ve_vl_vbrv_vvmvl,                          // llvm.ve.vl.vbrv.vvmvl (IntrinsicsVEVL.gen.td:436)
    ve_vl_vbrv_vvvl,                           // llvm.ve.vl.vbrv.vvvl (IntrinsicsVEVL.gen.td:435)
    ve_vl_vcmpsl_vsvl,                         // llvm.ve.vl.vcmpsl.vsvl (IntrinsicsVEVL.gen.td:310)
    ve_vl_vcmpsl_vsvmvl,                       // llvm.ve.vl.vcmpsl.vsvmvl (IntrinsicsVEVL.gen.td:313)
    ve_vl_vcmpsl_vsvvl,                        // llvm.ve.vl.vcmpsl.vsvvl (IntrinsicsVEVL.gen.td:311)
    ve_vl_vcmpsl_vvvl,                         // llvm.ve.vl.vcmpsl.vvvl (IntrinsicsVEVL.gen.td:308)
    ve_vl_vcmpsl_vvvmvl,                       // llvm.ve.vl.vcmpsl.vvvmvl (IntrinsicsVEVL.gen.td:312)
    ve_vl_vcmpsl_vvvvl,                        // llvm.ve.vl.vcmpsl.vvvvl (IntrinsicsVEVL.gen.td:309)
    ve_vl_vcmpswsx_vsvl,                       // llvm.ve.vl.vcmpswsx.vsvl (IntrinsicsVEVL.gen.td:292)
    ve_vl_vcmpswsx_vsvmvl,                     // llvm.ve.vl.vcmpswsx.vsvmvl (IntrinsicsVEVL.gen.td:295)
    ve_vl_vcmpswsx_vsvvl,                      // llvm.ve.vl.vcmpswsx.vsvvl (IntrinsicsVEVL.gen.td:293)
    ve_vl_vcmpswsx_vvvl,                       // llvm.ve.vl.vcmpswsx.vvvl (IntrinsicsVEVL.gen.td:290)
    ve_vl_vcmpswsx_vvvmvl,                     // llvm.ve.vl.vcmpswsx.vvvmvl (IntrinsicsVEVL.gen.td:294)
    ve_vl_vcmpswsx_vvvvl,                      // llvm.ve.vl.vcmpswsx.vvvvl (IntrinsicsVEVL.gen.td:291)
    ve_vl_vcmpswzx_vsvl,                       // llvm.ve.vl.vcmpswzx.vsvl (IntrinsicsVEVL.gen.td:298)
    ve_vl_vcmpswzx_vsvmvl,                     // llvm.ve.vl.vcmpswzx.vsvmvl (IntrinsicsVEVL.gen.td:301)
    ve_vl_vcmpswzx_vsvvl,                      // llvm.ve.vl.vcmpswzx.vsvvl (IntrinsicsVEVL.gen.td:299)
    ve_vl_vcmpswzx_vvvl,                       // llvm.ve.vl.vcmpswzx.vvvl (IntrinsicsVEVL.gen.td:296)
    ve_vl_vcmpswzx_vvvmvl,                     // llvm.ve.vl.vcmpswzx.vvvmvl (IntrinsicsVEVL.gen.td:300)
    ve_vl_vcmpswzx_vvvvl,                      // llvm.ve.vl.vcmpswzx.vvvvl (IntrinsicsVEVL.gen.td:297)
    ve_vl_vcmpul_vsvl,                         // llvm.ve.vl.vcmpul.vsvl (IntrinsicsVEVL.gen.td:274)
    ve_vl_vcmpul_vsvmvl,                       // llvm.ve.vl.vcmpul.vsvmvl (IntrinsicsVEVL.gen.td:277)
    ve_vl_vcmpul_vsvvl,                        // llvm.ve.vl.vcmpul.vsvvl (IntrinsicsVEVL.gen.td:275)
    ve_vl_vcmpul_vvvl,                         // llvm.ve.vl.vcmpul.vvvl (IntrinsicsVEVL.gen.td:272)
    ve_vl_vcmpul_vvvmvl,                       // llvm.ve.vl.vcmpul.vvvmvl (IntrinsicsVEVL.gen.td:276)
    ve_vl_vcmpul_vvvvl,                        // llvm.ve.vl.vcmpul.vvvvl (IntrinsicsVEVL.gen.td:273)
    ve_vl_vcmpuw_vsvl,                         // llvm.ve.vl.vcmpuw.vsvl (IntrinsicsVEVL.gen.td:280)
    ve_vl_vcmpuw_vsvmvl,                       // llvm.ve.vl.vcmpuw.vsvmvl (IntrinsicsVEVL.gen.td:283)
    ve_vl_vcmpuw_vsvvl,                        // llvm.ve.vl.vcmpuw.vsvvl (IntrinsicsVEVL.gen.td:281)
    ve_vl_vcmpuw_vvvl,                         // llvm.ve.vl.vcmpuw.vvvl (IntrinsicsVEVL.gen.td:278)
    ve_vl_vcmpuw_vvvmvl,                       // llvm.ve.vl.vcmpuw.vvvmvl (IntrinsicsVEVL.gen.td:282)
    ve_vl_vcmpuw_vvvvl,                        // llvm.ve.vl.vcmpuw.vvvvl (IntrinsicsVEVL.gen.td:279)
    ve_vl_vcp_vvmvl,                           // llvm.ve.vl.vcp.vvmvl (IntrinsicsVEVL.gen.td:837)
    ve_vl_vcvtdl_vvl,                          // llvm.ve.vl.vcvtdl.vvl (IntrinsicsVEVL.gen.td:821)
    ve_vl_vcvtdl_vvvl,                         // llvm.ve.vl.vcvtdl.vvvl (IntrinsicsVEVL.gen.td:822)
    ve_vl_vcvtds_vvl,                          // llvm.ve.vl.vcvtds.vvl (IntrinsicsVEVL.gen.td:823)
    ve_vl_vcvtds_vvvl,                         // llvm.ve.vl.vcvtds.vvvl (IntrinsicsVEVL.gen.td:824)
    ve_vl_vcvtdw_vvl,                          // llvm.ve.vl.vcvtdw.vvl (IntrinsicsVEVL.gen.td:815)
    ve_vl_vcvtdw_vvvl,                         // llvm.ve.vl.vcvtdw.vvvl (IntrinsicsVEVL.gen.td:816)
    ve_vl_vcvtld_vvl,                          // llvm.ve.vl.vcvtld.vvl (IntrinsicsVEVL.gen.td:809)
    ve_vl_vcvtld_vvmvl,                        // llvm.ve.vl.vcvtld.vvmvl (IntrinsicsVEVL.gen.td:811)
    ve_vl_vcvtld_vvvl,                         // llvm.ve.vl.vcvtld.vvvl (IntrinsicsVEVL.gen.td:810)
    ve_vl_vcvtldrz_vvl,                        // llvm.ve.vl.vcvtldrz.vvl (IntrinsicsVEVL.gen.td:812)
    ve_vl_vcvtldrz_vvmvl,                      // llvm.ve.vl.vcvtldrz.vvmvl (IntrinsicsVEVL.gen.td:814)
    ve_vl_vcvtldrz_vvvl,                       // llvm.ve.vl.vcvtldrz.vvvl (IntrinsicsVEVL.gen.td:813)
    ve_vl_vcvtsd_vvl,                          // llvm.ve.vl.vcvtsd.vvl (IntrinsicsVEVL.gen.td:825)
    ve_vl_vcvtsd_vvvl,                         // llvm.ve.vl.vcvtsd.vvvl (IntrinsicsVEVL.gen.td:826)
    ve_vl_vcvtsw_vvl,                          // llvm.ve.vl.vcvtsw.vvl (IntrinsicsVEVL.gen.td:817)
    ve_vl_vcvtsw_vvvl,                         // llvm.ve.vl.vcvtsw.vvvl (IntrinsicsVEVL.gen.td:818)
    ve_vl_vcvtwdsx_vvl,                        // llvm.ve.vl.vcvtwdsx.vvl (IntrinsicsVEVL.gen.td:779)
    ve_vl_vcvtwdsx_vvmvl,                      // llvm.ve.vl.vcvtwdsx.vvmvl (IntrinsicsVEVL.gen.td:781)
    ve_vl_vcvtwdsx_vvvl,                       // llvm.ve.vl.vcvtwdsx.vvvl (IntrinsicsVEVL.gen.td:780)
    ve_vl_vcvtwdsxrz_vvl,                      // llvm.ve.vl.vcvtwdsxrz.vvl (IntrinsicsVEVL.gen.td:782)
    ve_vl_vcvtwdsxrz_vvmvl,                    // llvm.ve.vl.vcvtwdsxrz.vvmvl (IntrinsicsVEVL.gen.td:784)
    ve_vl_vcvtwdsxrz_vvvl,                     // llvm.ve.vl.vcvtwdsxrz.vvvl (IntrinsicsVEVL.gen.td:783)
    ve_vl_vcvtwdzx_vvl,                        // llvm.ve.vl.vcvtwdzx.vvl (IntrinsicsVEVL.gen.td:785)
    ve_vl_vcvtwdzx_vvmvl,                      // llvm.ve.vl.vcvtwdzx.vvmvl (IntrinsicsVEVL.gen.td:787)
    ve_vl_vcvtwdzx_vvvl,                       // llvm.ve.vl.vcvtwdzx.vvvl (IntrinsicsVEVL.gen.td:786)
    ve_vl_vcvtwdzxrz_vvl,                      // llvm.ve.vl.vcvtwdzxrz.vvl (IntrinsicsVEVL.gen.td:788)
    ve_vl_vcvtwdzxrz_vvmvl,                    // llvm.ve.vl.vcvtwdzxrz.vvmvl (IntrinsicsVEVL.gen.td:790)
    ve_vl_vcvtwdzxrz_vvvl,                     // llvm.ve.vl.vcvtwdzxrz.vvvl (IntrinsicsVEVL.gen.td:789)
    ve_vl_vcvtwssx_vvl,                        // llvm.ve.vl.vcvtwssx.vvl (IntrinsicsVEVL.gen.td:791)
    ve_vl_vcvtwssx_vvmvl,                      // llvm.ve.vl.vcvtwssx.vvmvl (IntrinsicsVEVL.gen.td:793)
    ve_vl_vcvtwssx_vvvl,                       // llvm.ve.vl.vcvtwssx.vvvl (IntrinsicsVEVL.gen.td:792)
    ve_vl_vcvtwssxrz_vvl,                      // llvm.ve.vl.vcvtwssxrz.vvl (IntrinsicsVEVL.gen.td:794)
    ve_vl_vcvtwssxrz_vvmvl,                    // llvm.ve.vl.vcvtwssxrz.vvmvl (IntrinsicsVEVL.gen.td:796)
    ve_vl_vcvtwssxrz_vvvl,                     // llvm.ve.vl.vcvtwssxrz.vvvl (IntrinsicsVEVL.gen.td:795)
    ve_vl_vcvtwszx_vvl,                        // llvm.ve.vl.vcvtwszx.vvl (IntrinsicsVEVL.gen.td:797)
    ve_vl_vcvtwszx_vvmvl,                      // llvm.ve.vl.vcvtwszx.vvmvl (IntrinsicsVEVL.gen.td:799)
    ve_vl_vcvtwszx_vvvl,                       // llvm.ve.vl.vcvtwszx.vvvl (IntrinsicsVEVL.gen.td:798)
    ve_vl_vcvtwszxrz_vvl,                      // llvm.ve.vl.vcvtwszxrz.vvl (IntrinsicsVEVL.gen.td:800)
    ve_vl_vcvtwszxrz_vvmvl,                    // llvm.ve.vl.vcvtwszxrz.vvmvl (IntrinsicsVEVL.gen.td:802)
    ve_vl_vcvtwszxrz_vvvl,                     // llvm.ve.vl.vcvtwszxrz.vvvl (IntrinsicsVEVL.gen.td:801)
    ve_vl_vdivsl_vsvl,                         // llvm.ve.vl.vdivsl.vsvl (IntrinsicsVEVL.gen.td:265)
    ve_vl_vdivsl_vsvmvl,                       // llvm.ve.vl.vdivsl.vsvmvl (IntrinsicsVEVL.gen.td:268)
    ve_vl_vdivsl_vsvvl,                        // llvm.ve.vl.vdivsl.vsvvl (IntrinsicsVEVL.gen.td:266)
    ve_vl_vdivsl_vvsl,                         // llvm.ve.vl.vdivsl.vvsl (IntrinsicsVEVL.gen.td:269)
    ve_vl_vdivsl_vvsmvl,                       // llvm.ve.vl.vdivsl.vvsmvl (IntrinsicsVEVL.gen.td:271)
    ve_vl_vdivsl_vvsvl,                        // llvm.ve.vl.vdivsl.vvsvl (IntrinsicsVEVL.gen.td:270)
    ve_vl_vdivsl_vvvl,                         // llvm.ve.vl.vdivsl.vvvl (IntrinsicsVEVL.gen.td:263)
    ve_vl_vdivsl_vvvmvl,                       // llvm.ve.vl.vdivsl.vvvmvl (IntrinsicsVEVL.gen.td:267)
    ve_vl_vdivsl_vvvvl,                        // llvm.ve.vl.vdivsl.vvvvl (IntrinsicsVEVL.gen.td:264)
    ve_vl_vdivswsx_vsvl,                       // llvm.ve.vl.vdivswsx.vsvl (IntrinsicsVEVL.gen.td:247)
    ve_vl_vdivswsx_vsvmvl,                     // llvm.ve.vl.vdivswsx.vsvmvl (IntrinsicsVEVL.gen.td:250)
    ve_vl_vdivswsx_vsvvl,                      // llvm.ve.vl.vdivswsx.vsvvl (IntrinsicsVEVL.gen.td:248)
    ve_vl_vdivswsx_vvsl,                       // llvm.ve.vl.vdivswsx.vvsl (IntrinsicsVEVL.gen.td:257)
    ve_vl_vdivswsx_vvsmvl,                     // llvm.ve.vl.vdivswsx.vvsmvl (IntrinsicsVEVL.gen.td:259)
    ve_vl_vdivswsx_vvsvl,                      // llvm.ve.vl.vdivswsx.vvsvl (IntrinsicsVEVL.gen.td:258)
    ve_vl_vdivswsx_vvvl,                       // llvm.ve.vl.vdivswsx.vvvl (IntrinsicsVEVL.gen.td:245)
    ve_vl_vdivswsx_vvvmvl,                     // llvm.ve.vl.vdivswsx.vvvmvl (IntrinsicsVEVL.gen.td:249)
    ve_vl_vdivswsx_vvvvl,                      // llvm.ve.vl.vdivswsx.vvvvl (IntrinsicsVEVL.gen.td:246)
    ve_vl_vdivswzx_vsvl,                       // llvm.ve.vl.vdivswzx.vsvl (IntrinsicsVEVL.gen.td:253)
    ve_vl_vdivswzx_vsvmvl,                     // llvm.ve.vl.vdivswzx.vsvmvl (IntrinsicsVEVL.gen.td:256)
    ve_vl_vdivswzx_vsvvl,                      // llvm.ve.vl.vdivswzx.vsvvl (IntrinsicsVEVL.gen.td:254)
    ve_vl_vdivswzx_vvsl,                       // llvm.ve.vl.vdivswzx.vvsl (IntrinsicsVEVL.gen.td:260)
    ve_vl_vdivswzx_vvsmvl,                     // llvm.ve.vl.vdivswzx.vvsmvl (IntrinsicsVEVL.gen.td:262)
    ve_vl_vdivswzx_vvsvl,                      // llvm.ve.vl.vdivswzx.vvsvl (IntrinsicsVEVL.gen.td:261)
    ve_vl_vdivswzx_vvvl,                       // llvm.ve.vl.vdivswzx.vvvl (IntrinsicsVEVL.gen.td:251)
    ve_vl_vdivswzx_vvvmvl,                     // llvm.ve.vl.vdivswzx.vvvmvl (IntrinsicsVEVL.gen.td:255)
    ve_vl_vdivswzx_vvvvl,                      // llvm.ve.vl.vdivswzx.vvvvl (IntrinsicsVEVL.gen.td:252)
    ve_vl_vdivul_vsvl,                         // llvm.ve.vl.vdivul.vsvl (IntrinsicsVEVL.gen.td:229)
    ve_vl_vdivul_vsvmvl,                       // llvm.ve.vl.vdivul.vsvmvl (IntrinsicsVEVL.gen.td:232)
    ve_vl_vdivul_vsvvl,                        // llvm.ve.vl.vdivul.vsvvl (IntrinsicsVEVL.gen.td:230)
    ve_vl_vdivul_vvsl,                         // llvm.ve.vl.vdivul.vvsl (IntrinsicsVEVL.gen.td:239)
    ve_vl_vdivul_vvsmvl,                       // llvm.ve.vl.vdivul.vvsmvl (IntrinsicsVEVL.gen.td:241)
    ve_vl_vdivul_vvsvl,                        // llvm.ve.vl.vdivul.vvsvl (IntrinsicsVEVL.gen.td:240)
    ve_vl_vdivul_vvvl,                         // llvm.ve.vl.vdivul.vvvl (IntrinsicsVEVL.gen.td:227)
    ve_vl_vdivul_vvvmvl,                       // llvm.ve.vl.vdivul.vvvmvl (IntrinsicsVEVL.gen.td:231)
    ve_vl_vdivul_vvvvl,                        // llvm.ve.vl.vdivul.vvvvl (IntrinsicsVEVL.gen.td:228)
    ve_vl_vdivuw_vsvl,                         // llvm.ve.vl.vdivuw.vsvl (IntrinsicsVEVL.gen.td:235)
    ve_vl_vdivuw_vsvmvl,                       // llvm.ve.vl.vdivuw.vsvmvl (IntrinsicsVEVL.gen.td:238)
    ve_vl_vdivuw_vsvvl,                        // llvm.ve.vl.vdivuw.vsvvl (IntrinsicsVEVL.gen.td:236)
    ve_vl_vdivuw_vvsl,                         // llvm.ve.vl.vdivuw.vvsl (IntrinsicsVEVL.gen.td:242)
    ve_vl_vdivuw_vvsmvl,                       // llvm.ve.vl.vdivuw.vvsmvl (IntrinsicsVEVL.gen.td:244)
    ve_vl_vdivuw_vvsvl,                        // llvm.ve.vl.vdivuw.vvsvl (IntrinsicsVEVL.gen.td:243)
    ve_vl_vdivuw_vvvl,                         // llvm.ve.vl.vdivuw.vvvl (IntrinsicsVEVL.gen.td:233)
    ve_vl_vdivuw_vvvmvl,                       // llvm.ve.vl.vdivuw.vvvmvl (IntrinsicsVEVL.gen.td:237)
    ve_vl_vdivuw_vvvvl,                        // llvm.ve.vl.vdivuw.vvvvl (IntrinsicsVEVL.gen.td:234)
    ve_vl_veqv_vsvl,                           // llvm.ve.vl.veqv.vsvl (IntrinsicsVEVL.gen.td:400)
    ve_vl_veqv_vsvmvl,                         // llvm.ve.vl.veqv.vsvmvl (IntrinsicsVEVL.gen.td:403)
    ve_vl_veqv_vsvvl,                          // llvm.ve.vl.veqv.vsvvl (IntrinsicsVEVL.gen.td:401)
    ve_vl_veqv_vvvl,                           // llvm.ve.vl.veqv.vvvl (IntrinsicsVEVL.gen.td:398)
    ve_vl_veqv_vvvmvl,                         // llvm.ve.vl.veqv.vvvmvl (IntrinsicsVEVL.gen.td:402)
    ve_vl_veqv_vvvvl,                          // llvm.ve.vl.veqv.vvvvl (IntrinsicsVEVL.gen.td:399)
    ve_vl_vex_vvmvl,                           // llvm.ve.vl.vex.vvmvl (IntrinsicsVEVL.gen.td:838)
    ve_vl_vfaddd_vsvl,                         // llvm.ve.vl.vfaddd.vsvl (IntrinsicsVEVL.gen.td:531)
    ve_vl_vfaddd_vsvmvl,                       // llvm.ve.vl.vfaddd.vsvmvl (IntrinsicsVEVL.gen.td:534)
    ve_vl_vfaddd_vsvvl,                        // llvm.ve.vl.vfaddd.vsvvl (IntrinsicsVEVL.gen.td:532)
    ve_vl_vfaddd_vvvl,                         // llvm.ve.vl.vfaddd.vvvl (IntrinsicsVEVL.gen.td:529)
    ve_vl_vfaddd_vvvmvl,                       // llvm.ve.vl.vfaddd.vvvmvl (IntrinsicsVEVL.gen.td:533)
    ve_vl_vfaddd_vvvvl,                        // llvm.ve.vl.vfaddd.vvvvl (IntrinsicsVEVL.gen.td:530)
    ve_vl_vfadds_vsvl,                         // llvm.ve.vl.vfadds.vsvl (IntrinsicsVEVL.gen.td:537)
    ve_vl_vfadds_vsvmvl,                       // llvm.ve.vl.vfadds.vsvmvl (IntrinsicsVEVL.gen.td:540)
    ve_vl_vfadds_vsvvl,                        // llvm.ve.vl.vfadds.vsvvl (IntrinsicsVEVL.gen.td:538)
    ve_vl_vfadds_vvvl,                         // llvm.ve.vl.vfadds.vvvl (IntrinsicsVEVL.gen.td:535)
    ve_vl_vfadds_vvvmvl,                       // llvm.ve.vl.vfadds.vvvmvl (IntrinsicsVEVL.gen.td:539)
    ve_vl_vfadds_vvvvl,                        // llvm.ve.vl.vfadds.vvvvl (IntrinsicsVEVL.gen.td:536)
    ve_vl_vfcmpd_vsvl,                         // llvm.ve.vl.vfcmpd.vsvl (IntrinsicsVEVL.gen.td:601)
    ve_vl_vfcmpd_vsvmvl,                       // llvm.ve.vl.vfcmpd.vsvmvl (IntrinsicsVEVL.gen.td:604)
    ve_vl_vfcmpd_vsvvl,                        // llvm.ve.vl.vfcmpd.vsvvl (IntrinsicsVEVL.gen.td:602)
    ve_vl_vfcmpd_vvvl,                         // llvm.ve.vl.vfcmpd.vvvl (IntrinsicsVEVL.gen.td:599)
    ve_vl_vfcmpd_vvvmvl,                       // llvm.ve.vl.vfcmpd.vvvmvl (IntrinsicsVEVL.gen.td:603)
    ve_vl_vfcmpd_vvvvl,                        // llvm.ve.vl.vfcmpd.vvvvl (IntrinsicsVEVL.gen.td:600)
    ve_vl_vfcmps_vsvl,                         // llvm.ve.vl.vfcmps.vsvl (IntrinsicsVEVL.gen.td:607)
    ve_vl_vfcmps_vsvmvl,                       // llvm.ve.vl.vfcmps.vsvmvl (IntrinsicsVEVL.gen.td:610)
    ve_vl_vfcmps_vsvvl,                        // llvm.ve.vl.vfcmps.vsvvl (IntrinsicsVEVL.gen.td:608)
    ve_vl_vfcmps_vvvl,                         // llvm.ve.vl.vfcmps.vvvl (IntrinsicsVEVL.gen.td:605)
    ve_vl_vfcmps_vvvmvl,                       // llvm.ve.vl.vfcmps.vvvmvl (IntrinsicsVEVL.gen.td:609)
    ve_vl_vfcmps_vvvvl,                        // llvm.ve.vl.vfcmps.vvvvl (IntrinsicsVEVL.gen.td:606)
    ve_vl_vfdivd_vsvl,                         // llvm.ve.vl.vfdivd.vsvl (IntrinsicsVEVL.gen.td:585)
    ve_vl_vfdivd_vsvmvl,                       // llvm.ve.vl.vfdivd.vsvmvl (IntrinsicsVEVL.gen.td:588)
    ve_vl_vfdivd_vsvvl,                        // llvm.ve.vl.vfdivd.vsvvl (IntrinsicsVEVL.gen.td:586)
    ve_vl_vfdivd_vvvl,                         // llvm.ve.vl.vfdivd.vvvl (IntrinsicsVEVL.gen.td:583)
    ve_vl_vfdivd_vvvmvl,                       // llvm.ve.vl.vfdivd.vvvmvl (IntrinsicsVEVL.gen.td:587)
    ve_vl_vfdivd_vvvvl,                        // llvm.ve.vl.vfdivd.vvvvl (IntrinsicsVEVL.gen.td:584)
    ve_vl_vfdivs_vsvl,                         // llvm.ve.vl.vfdivs.vsvl (IntrinsicsVEVL.gen.td:591)
    ve_vl_vfdivs_vsvmvl,                       // llvm.ve.vl.vfdivs.vsvmvl (IntrinsicsVEVL.gen.td:594)
    ve_vl_vfdivs_vsvvl,                        // llvm.ve.vl.vfdivs.vsvvl (IntrinsicsVEVL.gen.td:592)
    ve_vl_vfdivs_vvvl,                         // llvm.ve.vl.vfdivs.vvvl (IntrinsicsVEVL.gen.td:589)
    ve_vl_vfdivs_vvvmvl,                       // llvm.ve.vl.vfdivs.vvvmvl (IntrinsicsVEVL.gen.td:593)
    ve_vl_vfdivs_vvvvl,                        // llvm.ve.vl.vfdivs.vvvvl (IntrinsicsVEVL.gen.td:590)
    ve_vl_vfmadd_vsvvl,                        // llvm.ve.vl.vfmadd.vsvvl (IntrinsicsVEVL.gen.td:655)
    ve_vl_vfmadd_vsvvmvl,                      // llvm.ve.vl.vfmadd.vsvvmvl (IntrinsicsVEVL.gen.td:660)
    ve_vl_vfmadd_vsvvvl,                       // llvm.ve.vl.vfmadd.vsvvvl (IntrinsicsVEVL.gen.td:656)
    ve_vl_vfmadd_vvsvl,                        // llvm.ve.vl.vfmadd.vvsvl (IntrinsicsVEVL.gen.td:657)
    ve_vl_vfmadd_vvsvmvl,                      // llvm.ve.vl.vfmadd.vvsvmvl (IntrinsicsVEVL.gen.td:661)
    ve_vl_vfmadd_vvsvvl,                       // llvm.ve.vl.vfmadd.vvsvvl (IntrinsicsVEVL.gen.td:658)
    ve_vl_vfmadd_vvvvl,                        // llvm.ve.vl.vfmadd.vvvvl (IntrinsicsVEVL.gen.td:653)
    ve_vl_vfmadd_vvvvmvl,                      // llvm.ve.vl.vfmadd.vvvvmvl (IntrinsicsVEVL.gen.td:659)
    ve_vl_vfmadd_vvvvvl,                       // llvm.ve.vl.vfmadd.vvvvvl (IntrinsicsVEVL.gen.td:654)
    ve_vl_vfmads_vsvvl,                        // llvm.ve.vl.vfmads.vsvvl (IntrinsicsVEVL.gen.td:664)
    ve_vl_vfmads_vsvvmvl,                      // llvm.ve.vl.vfmads.vsvvmvl (IntrinsicsVEVL.gen.td:669)
    ve_vl_vfmads_vsvvvl,                       // llvm.ve.vl.vfmads.vsvvvl (IntrinsicsVEVL.gen.td:665)
    ve_vl_vfmads_vvsvl,                        // llvm.ve.vl.vfmads.vvsvl (IntrinsicsVEVL.gen.td:666)
    ve_vl_vfmads_vvsvmvl,                      // llvm.ve.vl.vfmads.vvsvmvl (IntrinsicsVEVL.gen.td:670)
    ve_vl_vfmads_vvsvvl,                       // llvm.ve.vl.vfmads.vvsvvl (IntrinsicsVEVL.gen.td:667)
    ve_vl_vfmads_vvvvl,                        // llvm.ve.vl.vfmads.vvvvl (IntrinsicsVEVL.gen.td:662)
    ve_vl_vfmads_vvvvmvl,                      // llvm.ve.vl.vfmads.vvvvmvl (IntrinsicsVEVL.gen.td:668)
    ve_vl_vfmads_vvvvvl,                       // llvm.ve.vl.vfmads.vvvvvl (IntrinsicsVEVL.gen.td:663)
    ve_vl_vfmaxd_vsvl,                         // llvm.ve.vl.vfmaxd.vsvl (IntrinsicsVEVL.gen.td:619)
    ve_vl_vfmaxd_vsvmvl,                       // llvm.ve.vl.vfmaxd.vsvmvl (IntrinsicsVEVL.gen.td:622)
    ve_vl_vfmaxd_vsvvl,                        // llvm.ve.vl.vfmaxd.vsvvl (IntrinsicsVEVL.gen.td:620)
    ve_vl_vfmaxd_vvvl,                         // llvm.ve.vl.vfmaxd.vvvl (IntrinsicsVEVL.gen.td:617)
    ve_vl_vfmaxd_vvvmvl,                       // llvm.ve.vl.vfmaxd.vvvmvl (IntrinsicsVEVL.gen.td:621)
    ve_vl_vfmaxd_vvvvl,                        // llvm.ve.vl.vfmaxd.vvvvl (IntrinsicsVEVL.gen.td:618)
    ve_vl_vfmaxs_vsvl,                         // llvm.ve.vl.vfmaxs.vsvl (IntrinsicsVEVL.gen.td:625)
    ve_vl_vfmaxs_vsvmvl,                       // llvm.ve.vl.vfmaxs.vsvmvl (IntrinsicsVEVL.gen.td:628)
    ve_vl_vfmaxs_vsvvl,                        // llvm.ve.vl.vfmaxs.vsvvl (IntrinsicsVEVL.gen.td:626)
    ve_vl_vfmaxs_vvvl,                         // llvm.ve.vl.vfmaxs.vvvl (IntrinsicsVEVL.gen.td:623)
    ve_vl_vfmaxs_vvvmvl,                       // llvm.ve.vl.vfmaxs.vvvmvl (IntrinsicsVEVL.gen.td:627)
    ve_vl_vfmaxs_vvvvl,                        // llvm.ve.vl.vfmaxs.vvvvl (IntrinsicsVEVL.gen.td:624)
    ve_vl_vfmind_vsvl,                         // llvm.ve.vl.vfmind.vsvl (IntrinsicsVEVL.gen.td:637)
    ve_vl_vfmind_vsvmvl,                       // llvm.ve.vl.vfmind.vsvmvl (IntrinsicsVEVL.gen.td:640)
    ve_vl_vfmind_vsvvl,                        // llvm.ve.vl.vfmind.vsvvl (IntrinsicsVEVL.gen.td:638)
    ve_vl_vfmind_vvvl,                         // llvm.ve.vl.vfmind.vvvl (IntrinsicsVEVL.gen.td:635)
    ve_vl_vfmind_vvvmvl,                       // llvm.ve.vl.vfmind.vvvmvl (IntrinsicsVEVL.gen.td:639)
    ve_vl_vfmind_vvvvl,                        // llvm.ve.vl.vfmind.vvvvl (IntrinsicsVEVL.gen.td:636)
    ve_vl_vfmins_vsvl,                         // llvm.ve.vl.vfmins.vsvl (IntrinsicsVEVL.gen.td:643)
    ve_vl_vfmins_vsvmvl,                       // llvm.ve.vl.vfmins.vsvmvl (IntrinsicsVEVL.gen.td:646)
    ve_vl_vfmins_vsvvl,                        // llvm.ve.vl.vfmins.vsvvl (IntrinsicsVEVL.gen.td:644)
    ve_vl_vfmins_vvvl,                         // llvm.ve.vl.vfmins.vvvl (IntrinsicsVEVL.gen.td:641)
    ve_vl_vfmins_vvvmvl,                       // llvm.ve.vl.vfmins.vvvmvl (IntrinsicsVEVL.gen.td:645)
    ve_vl_vfmins_vvvvl,                        // llvm.ve.vl.vfmins.vvvvl (IntrinsicsVEVL.gen.td:642)
    ve_vl_vfmkdeq_mvl,                         // llvm.ve.vl.vfmkdeq.mvl (IntrinsicsVEVL.gen.td:989)
    ve_vl_vfmkdeq_mvml,                        // llvm.ve.vl.vfmkdeq.mvml (IntrinsicsVEVL.gen.td:990)
    ve_vl_vfmkdeqnan_mvl,                      // llvm.ve.vl.vfmkdeqnan.mvl (IntrinsicsVEVL.gen.td:1005)
    ve_vl_vfmkdeqnan_mvml,                     // llvm.ve.vl.vfmkdeqnan.mvml (IntrinsicsVEVL.gen.td:1006)
    ve_vl_vfmkdge_mvl,                         // llvm.ve.vl.vfmkdge.mvl (IntrinsicsVEVL.gen.td:991)
    ve_vl_vfmkdge_mvml,                        // llvm.ve.vl.vfmkdge.mvml (IntrinsicsVEVL.gen.td:992)
    ve_vl_vfmkdgenan_mvl,                      // llvm.ve.vl.vfmkdgenan.mvl (IntrinsicsVEVL.gen.td:1007)
    ve_vl_vfmkdgenan_mvml,                     // llvm.ve.vl.vfmkdgenan.mvml (IntrinsicsVEVL.gen.td:1008)
    ve_vl_vfmkdgt_mvl,                         // llvm.ve.vl.vfmkdgt.mvl (IntrinsicsVEVL.gen.td:983)
    ve_vl_vfmkdgt_mvml,                        // llvm.ve.vl.vfmkdgt.mvml (IntrinsicsVEVL.gen.td:984)
    ve_vl_vfmkdgtnan_mvl,                      // llvm.ve.vl.vfmkdgtnan.mvl (IntrinsicsVEVL.gen.td:999)
    ve_vl_vfmkdgtnan_mvml,                     // llvm.ve.vl.vfmkdgtnan.mvml (IntrinsicsVEVL.gen.td:1000)
    ve_vl_vfmkdle_mvl,                         // llvm.ve.vl.vfmkdle.mvl (IntrinsicsVEVL.gen.td:993)
    ve_vl_vfmkdle_mvml,                        // llvm.ve.vl.vfmkdle.mvml (IntrinsicsVEVL.gen.td:994)
    ve_vl_vfmkdlenan_mvl,                      // llvm.ve.vl.vfmkdlenan.mvl (IntrinsicsVEVL.gen.td:1009)
    ve_vl_vfmkdlenan_mvml,                     // llvm.ve.vl.vfmkdlenan.mvml (IntrinsicsVEVL.gen.td:1010)
    ve_vl_vfmkdlt_mvl,                         // llvm.ve.vl.vfmkdlt.mvl (IntrinsicsVEVL.gen.td:985)
    ve_vl_vfmkdlt_mvml,                        // llvm.ve.vl.vfmkdlt.mvml (IntrinsicsVEVL.gen.td:986)
    ve_vl_vfmkdltnan_mvl,                      // llvm.ve.vl.vfmkdltnan.mvl (IntrinsicsVEVL.gen.td:1001)
    ve_vl_vfmkdltnan_mvml,                     // llvm.ve.vl.vfmkdltnan.mvml (IntrinsicsVEVL.gen.td:1002)
    ve_vl_vfmkdnan_mvl,                        // llvm.ve.vl.vfmkdnan.mvl (IntrinsicsVEVL.gen.td:997)
    ve_vl_vfmkdnan_mvml,                       // llvm.ve.vl.vfmkdnan.mvml (IntrinsicsVEVL.gen.td:998)
    ve_vl_vfmkdne_mvl,                         // llvm.ve.vl.vfmkdne.mvl (IntrinsicsVEVL.gen.td:987)
    ve_vl_vfmkdne_mvml,                        // llvm.ve.vl.vfmkdne.mvml (IntrinsicsVEVL.gen.td:988)
    ve_vl_vfmkdnenan_mvl,                      // llvm.ve.vl.vfmkdnenan.mvl (IntrinsicsVEVL.gen.td:1003)
    ve_vl_vfmkdnenan_mvml,                     // llvm.ve.vl.vfmkdnenan.mvml (IntrinsicsVEVL.gen.td:1004)
    ve_vl_vfmkdnum_mvl,                        // llvm.ve.vl.vfmkdnum.mvl (IntrinsicsVEVL.gen.td:995)
    ve_vl_vfmkdnum_mvml,                       // llvm.ve.vl.vfmkdnum.mvml (IntrinsicsVEVL.gen.td:996)
    ve_vl_vfmklaf_ml,                          // llvm.ve.vl.vfmklaf.ml (IntrinsicsVEVL.gen.td:840)
    ve_vl_vfmklat_ml,                          // llvm.ve.vl.vfmklat.ml (IntrinsicsVEVL.gen.td:839)
    ve_vl_vfmkleq_mvl,                         // llvm.ve.vl.vfmkleq.mvl (IntrinsicsVEVL.gen.td:849)
    ve_vl_vfmkleq_mvml,                        // llvm.ve.vl.vfmkleq.mvml (IntrinsicsVEVL.gen.td:850)
    ve_vl_vfmkleqnan_mvl,                      // llvm.ve.vl.vfmkleqnan.mvl (IntrinsicsVEVL.gen.td:865)
    ve_vl_vfmkleqnan_mvml,                     // llvm.ve.vl.vfmkleqnan.mvml (IntrinsicsVEVL.gen.td:866)
    ve_vl_vfmklge_mvl,                         // llvm.ve.vl.vfmklge.mvl (IntrinsicsVEVL.gen.td:851)
    ve_vl_vfmklge_mvml,                        // llvm.ve.vl.vfmklge.mvml (IntrinsicsVEVL.gen.td:852)
    ve_vl_vfmklgenan_mvl,                      // llvm.ve.vl.vfmklgenan.mvl (IntrinsicsVEVL.gen.td:867)
    ve_vl_vfmklgenan_mvml,                     // llvm.ve.vl.vfmklgenan.mvml (IntrinsicsVEVL.gen.td:868)
    ve_vl_vfmklgt_mvl,                         // llvm.ve.vl.vfmklgt.mvl (IntrinsicsVEVL.gen.td:843)
    ve_vl_vfmklgt_mvml,                        // llvm.ve.vl.vfmklgt.mvml (IntrinsicsVEVL.gen.td:844)
    ve_vl_vfmklgtnan_mvl,                      // llvm.ve.vl.vfmklgtnan.mvl (IntrinsicsVEVL.gen.td:859)
    ve_vl_vfmklgtnan_mvml,                     // llvm.ve.vl.vfmklgtnan.mvml (IntrinsicsVEVL.gen.td:860)
    ve_vl_vfmklle_mvl,                         // llvm.ve.vl.vfmklle.mvl (IntrinsicsVEVL.gen.td:853)
    ve_vl_vfmklle_mvml,                        // llvm.ve.vl.vfmklle.mvml (IntrinsicsVEVL.gen.td:854)
    ve_vl_vfmkllenan_mvl,                      // llvm.ve.vl.vfmkllenan.mvl (IntrinsicsVEVL.gen.td:869)
    ve_vl_vfmkllenan_mvml,                     // llvm.ve.vl.vfmkllenan.mvml (IntrinsicsVEVL.gen.td:870)
    ve_vl_vfmkllt_mvl,                         // llvm.ve.vl.vfmkllt.mvl (IntrinsicsVEVL.gen.td:845)
    ve_vl_vfmkllt_mvml,                        // llvm.ve.vl.vfmkllt.mvml (IntrinsicsVEVL.gen.td:846)
    ve_vl_vfmklltnan_mvl,                      // llvm.ve.vl.vfmklltnan.mvl (IntrinsicsVEVL.gen.td:861)
    ve_vl_vfmklltnan_mvml,                     // llvm.ve.vl.vfmklltnan.mvml (IntrinsicsVEVL.gen.td:862)
    ve_vl_vfmklnan_mvl,                        // llvm.ve.vl.vfmklnan.mvl (IntrinsicsVEVL.gen.td:857)
    ve_vl_vfmklnan_mvml,                       // llvm.ve.vl.vfmklnan.mvml (IntrinsicsVEVL.gen.td:858)
    ve_vl_vfmklne_mvl,                         // llvm.ve.vl.vfmklne.mvl (IntrinsicsVEVL.gen.td:847)
    ve_vl_vfmklne_mvml,                        // llvm.ve.vl.vfmklne.mvml (IntrinsicsVEVL.gen.td:848)
    ve_vl_vfmklnenan_mvl,                      // llvm.ve.vl.vfmklnenan.mvl (IntrinsicsVEVL.gen.td:863)
    ve_vl_vfmklnenan_mvml,                     // llvm.ve.vl.vfmklnenan.mvml (IntrinsicsVEVL.gen.td:864)
    ve_vl_vfmklnum_mvl,                        // llvm.ve.vl.vfmklnum.mvl (IntrinsicsVEVL.gen.td:855)
    ve_vl_vfmklnum_mvml,                       // llvm.ve.vl.vfmklnum.mvml (IntrinsicsVEVL.gen.td:856)
    ve_vl_vfmkseq_mvl,                         // llvm.ve.vl.vfmkseq.mvl (IntrinsicsVEVL.gen.td:1017)
    ve_vl_vfmkseq_mvml,                        // llvm.ve.vl.vfmkseq.mvml (IntrinsicsVEVL.gen.td:1018)
    ve_vl_vfmkseqnan_mvl,                      // llvm.ve.vl.vfmkseqnan.mvl (IntrinsicsVEVL.gen.td:1033)
    ve_vl_vfmkseqnan_mvml,                     // llvm.ve.vl.vfmkseqnan.mvml (IntrinsicsVEVL.gen.td:1034)
    ve_vl_vfmksge_mvl,                         // llvm.ve.vl.vfmksge.mvl (IntrinsicsVEVL.gen.td:1019)
    ve_vl_vfmksge_mvml,                        // llvm.ve.vl.vfmksge.mvml (IntrinsicsVEVL.gen.td:1020)
    ve_vl_vfmksgenan_mvl,                      // llvm.ve.vl.vfmksgenan.mvl (IntrinsicsVEVL.gen.td:1035)
    ve_vl_vfmksgenan_mvml,                     // llvm.ve.vl.vfmksgenan.mvml (IntrinsicsVEVL.gen.td:1036)
    ve_vl_vfmksgt_mvl,                         // llvm.ve.vl.vfmksgt.mvl (IntrinsicsVEVL.gen.td:1011)
    ve_vl_vfmksgt_mvml,                        // llvm.ve.vl.vfmksgt.mvml (IntrinsicsVEVL.gen.td:1012)
    ve_vl_vfmksgtnan_mvl,                      // llvm.ve.vl.vfmksgtnan.mvl (IntrinsicsVEVL.gen.td:1027)
    ve_vl_vfmksgtnan_mvml,                     // llvm.ve.vl.vfmksgtnan.mvml (IntrinsicsVEVL.gen.td:1028)
    ve_vl_vfmksle_mvl,                         // llvm.ve.vl.vfmksle.mvl (IntrinsicsVEVL.gen.td:1021)
    ve_vl_vfmksle_mvml,                        // llvm.ve.vl.vfmksle.mvml (IntrinsicsVEVL.gen.td:1022)
    ve_vl_vfmkslenan_mvl,                      // llvm.ve.vl.vfmkslenan.mvl (IntrinsicsVEVL.gen.td:1037)
    ve_vl_vfmkslenan_mvml,                     // llvm.ve.vl.vfmkslenan.mvml (IntrinsicsVEVL.gen.td:1038)
    ve_vl_vfmkslt_mvl,                         // llvm.ve.vl.vfmkslt.mvl (IntrinsicsVEVL.gen.td:1013)
    ve_vl_vfmkslt_mvml,                        // llvm.ve.vl.vfmkslt.mvml (IntrinsicsVEVL.gen.td:1014)
    ve_vl_vfmksltnan_mvl,                      // llvm.ve.vl.vfmksltnan.mvl (IntrinsicsVEVL.gen.td:1029)
    ve_vl_vfmksltnan_mvml,                     // llvm.ve.vl.vfmksltnan.mvml (IntrinsicsVEVL.gen.td:1030)
    ve_vl_vfmksnan_mvl,                        // llvm.ve.vl.vfmksnan.mvl (IntrinsicsVEVL.gen.td:1025)
    ve_vl_vfmksnan_mvml,                       // llvm.ve.vl.vfmksnan.mvml (IntrinsicsVEVL.gen.td:1026)
    ve_vl_vfmksne_mvl,                         // llvm.ve.vl.vfmksne.mvl (IntrinsicsVEVL.gen.td:1015)
    ve_vl_vfmksne_mvml,                        // llvm.ve.vl.vfmksne.mvml (IntrinsicsVEVL.gen.td:1016)
    ve_vl_vfmksnenan_mvl,                      // llvm.ve.vl.vfmksnenan.mvl (IntrinsicsVEVL.gen.td:1031)
    ve_vl_vfmksnenan_mvml,                     // llvm.ve.vl.vfmksnenan.mvml (IntrinsicsVEVL.gen.td:1032)
    ve_vl_vfmksnum_mvl,                        // llvm.ve.vl.vfmksnum.mvl (IntrinsicsVEVL.gen.td:1023)
    ve_vl_vfmksnum_mvml,                       // llvm.ve.vl.vfmksnum.mvml (IntrinsicsVEVL.gen.td:1024)
    ve_vl_vfmkweq_mvl,                         // llvm.ve.vl.vfmkweq.mvl (IntrinsicsVEVL.gen.td:877)
    ve_vl_vfmkweq_mvml,                        // llvm.ve.vl.vfmkweq.mvml (IntrinsicsVEVL.gen.td:878)
    ve_vl_vfmkweqnan_mvl,                      // llvm.ve.vl.vfmkweqnan.mvl (IntrinsicsVEVL.gen.td:893)
    ve_vl_vfmkweqnan_mvml,                     // llvm.ve.vl.vfmkweqnan.mvml (IntrinsicsVEVL.gen.td:894)
    ve_vl_vfmkwge_mvl,                         // llvm.ve.vl.vfmkwge.mvl (IntrinsicsVEVL.gen.td:879)
    ve_vl_vfmkwge_mvml,                        // llvm.ve.vl.vfmkwge.mvml (IntrinsicsVEVL.gen.td:880)
    ve_vl_vfmkwgenan_mvl,                      // llvm.ve.vl.vfmkwgenan.mvl (IntrinsicsVEVL.gen.td:895)
    ve_vl_vfmkwgenan_mvml,                     // llvm.ve.vl.vfmkwgenan.mvml (IntrinsicsVEVL.gen.td:896)
    ve_vl_vfmkwgt_mvl,                         // llvm.ve.vl.vfmkwgt.mvl (IntrinsicsVEVL.gen.td:871)
    ve_vl_vfmkwgt_mvml,                        // llvm.ve.vl.vfmkwgt.mvml (IntrinsicsVEVL.gen.td:872)
    ve_vl_vfmkwgtnan_mvl,                      // llvm.ve.vl.vfmkwgtnan.mvl (IntrinsicsVEVL.gen.td:887)
    ve_vl_vfmkwgtnan_mvml,                     // llvm.ve.vl.vfmkwgtnan.mvml (IntrinsicsVEVL.gen.td:888)
    ve_vl_vfmkwle_mvl,                         // llvm.ve.vl.vfmkwle.mvl (IntrinsicsVEVL.gen.td:881)
    ve_vl_vfmkwle_mvml,                        // llvm.ve.vl.vfmkwle.mvml (IntrinsicsVEVL.gen.td:882)
    ve_vl_vfmkwlenan_mvl,                      // llvm.ve.vl.vfmkwlenan.mvl (IntrinsicsVEVL.gen.td:897)
    ve_vl_vfmkwlenan_mvml,                     // llvm.ve.vl.vfmkwlenan.mvml (IntrinsicsVEVL.gen.td:898)
    ve_vl_vfmkwlt_mvl,                         // llvm.ve.vl.vfmkwlt.mvl (IntrinsicsVEVL.gen.td:873)
    ve_vl_vfmkwlt_mvml,                        // llvm.ve.vl.vfmkwlt.mvml (IntrinsicsVEVL.gen.td:874)
    ve_vl_vfmkwltnan_mvl,                      // llvm.ve.vl.vfmkwltnan.mvl (IntrinsicsVEVL.gen.td:889)
    ve_vl_vfmkwltnan_mvml,                     // llvm.ve.vl.vfmkwltnan.mvml (IntrinsicsVEVL.gen.td:890)
    ve_vl_vfmkwnan_mvl,                        // llvm.ve.vl.vfmkwnan.mvl (IntrinsicsVEVL.gen.td:885)
    ve_vl_vfmkwnan_mvml,                       // llvm.ve.vl.vfmkwnan.mvml (IntrinsicsVEVL.gen.td:886)
    ve_vl_vfmkwne_mvl,                         // llvm.ve.vl.vfmkwne.mvl (IntrinsicsVEVL.gen.td:875)
    ve_vl_vfmkwne_mvml,                        // llvm.ve.vl.vfmkwne.mvml (IntrinsicsVEVL.gen.td:876)
    ve_vl_vfmkwnenan_mvl,                      // llvm.ve.vl.vfmkwnenan.mvl (IntrinsicsVEVL.gen.td:891)
    ve_vl_vfmkwnenan_mvml,                     // llvm.ve.vl.vfmkwnenan.mvml (IntrinsicsVEVL.gen.td:892)
    ve_vl_vfmkwnum_mvl,                        // llvm.ve.vl.vfmkwnum.mvl (IntrinsicsVEVL.gen.td:883)
    ve_vl_vfmkwnum_mvml,                       // llvm.ve.vl.vfmkwnum.mvml (IntrinsicsVEVL.gen.td:884)
    ve_vl_vfmsbd_vsvvl,                        // llvm.ve.vl.vfmsbd.vsvvl (IntrinsicsVEVL.gen.td:682)
    ve_vl_vfmsbd_vsvvmvl,                      // llvm.ve.vl.vfmsbd.vsvvmvl (IntrinsicsVEVL.gen.td:687)
    ve_vl_vfmsbd_vsvvvl,                       // llvm.ve.vl.vfmsbd.vsvvvl (IntrinsicsVEVL.gen.td:683)
    ve_vl_vfmsbd_vvsvl,                        // llvm.ve.vl.vfmsbd.vvsvl (IntrinsicsVEVL.gen.td:684)
    ve_vl_vfmsbd_vvsvmvl,                      // llvm.ve.vl.vfmsbd.vvsvmvl (IntrinsicsVEVL.gen.td:688)
    ve_vl_vfmsbd_vvsvvl,                       // llvm.ve.vl.vfmsbd.vvsvvl (IntrinsicsVEVL.gen.td:685)
    ve_vl_vfmsbd_vvvvl,                        // llvm.ve.vl.vfmsbd.vvvvl (IntrinsicsVEVL.gen.td:680)
    ve_vl_vfmsbd_vvvvmvl,                      // llvm.ve.vl.vfmsbd.vvvvmvl (IntrinsicsVEVL.gen.td:686)
    ve_vl_vfmsbd_vvvvvl,                       // llvm.ve.vl.vfmsbd.vvvvvl (IntrinsicsVEVL.gen.td:681)
    ve_vl_vfmsbs_vsvvl,                        // llvm.ve.vl.vfmsbs.vsvvl (IntrinsicsVEVL.gen.td:691)
    ve_vl_vfmsbs_vsvvmvl,                      // llvm.ve.vl.vfmsbs.vsvvmvl (IntrinsicsVEVL.gen.td:696)
    ve_vl_vfmsbs_vsvvvl,                       // llvm.ve.vl.vfmsbs.vsvvvl (IntrinsicsVEVL.gen.td:692)
    ve_vl_vfmsbs_vvsvl,                        // llvm.ve.vl.vfmsbs.vvsvl (IntrinsicsVEVL.gen.td:693)
    ve_vl_vfmsbs_vvsvmvl,                      // llvm.ve.vl.vfmsbs.vvsvmvl (IntrinsicsVEVL.gen.td:697)
    ve_vl_vfmsbs_vvsvvl,                       // llvm.ve.vl.vfmsbs.vvsvvl (IntrinsicsVEVL.gen.td:694)
    ve_vl_vfmsbs_vvvvl,                        // llvm.ve.vl.vfmsbs.vvvvl (IntrinsicsVEVL.gen.td:689)
    ve_vl_vfmsbs_vvvvmvl,                      // llvm.ve.vl.vfmsbs.vvvvmvl (IntrinsicsVEVL.gen.td:695)
    ve_vl_vfmsbs_vvvvvl,                       // llvm.ve.vl.vfmsbs.vvvvvl (IntrinsicsVEVL.gen.td:690)
    ve_vl_vfmuld_vsvl,                         // llvm.ve.vl.vfmuld.vsvl (IntrinsicsVEVL.gen.td:567)
    ve_vl_vfmuld_vsvmvl,                       // llvm.ve.vl.vfmuld.vsvmvl (IntrinsicsVEVL.gen.td:570)
    ve_vl_vfmuld_vsvvl,                        // llvm.ve.vl.vfmuld.vsvvl (IntrinsicsVEVL.gen.td:568)
    ve_vl_vfmuld_vvvl,                         // llvm.ve.vl.vfmuld.vvvl (IntrinsicsVEVL.gen.td:565)
    ve_vl_vfmuld_vvvmvl,                       // llvm.ve.vl.vfmuld.vvvmvl (IntrinsicsVEVL.gen.td:569)
    ve_vl_vfmuld_vvvvl,                        // llvm.ve.vl.vfmuld.vvvvl (IntrinsicsVEVL.gen.td:566)
    ve_vl_vfmuls_vsvl,                         // llvm.ve.vl.vfmuls.vsvl (IntrinsicsVEVL.gen.td:573)
    ve_vl_vfmuls_vsvmvl,                       // llvm.ve.vl.vfmuls.vsvmvl (IntrinsicsVEVL.gen.td:576)
    ve_vl_vfmuls_vsvvl,                        // llvm.ve.vl.vfmuls.vsvvl (IntrinsicsVEVL.gen.td:574)
    ve_vl_vfmuls_vvvl,                         // llvm.ve.vl.vfmuls.vvvl (IntrinsicsVEVL.gen.td:571)
    ve_vl_vfmuls_vvvmvl,                       // llvm.ve.vl.vfmuls.vvvmvl (IntrinsicsVEVL.gen.td:575)
    ve_vl_vfmuls_vvvvl,                        // llvm.ve.vl.vfmuls.vvvvl (IntrinsicsVEVL.gen.td:572)
    ve_vl_vfnmadd_vsvvl,                       // llvm.ve.vl.vfnmadd.vsvvl (IntrinsicsVEVL.gen.td:709)
    ve_vl_vfnmadd_vsvvmvl,                     // llvm.ve.vl.vfnmadd.vsvvmvl (IntrinsicsVEVL.gen.td:714)
    ve_vl_vfnmadd_vsvvvl,                      // llvm.ve.vl.vfnmadd.vsvvvl (IntrinsicsVEVL.gen.td:710)
    ve_vl_vfnmadd_vvsvl,                       // llvm.ve.vl.vfnmadd.vvsvl (IntrinsicsVEVL.gen.td:711)
    ve_vl_vfnmadd_vvsvmvl,                     // llvm.ve.vl.vfnmadd.vvsvmvl (IntrinsicsVEVL.gen.td:715)
    ve_vl_vfnmadd_vvsvvl,                      // llvm.ve.vl.vfnmadd.vvsvvl (IntrinsicsVEVL.gen.td:712)
    ve_vl_vfnmadd_vvvvl,                       // llvm.ve.vl.vfnmadd.vvvvl (IntrinsicsVEVL.gen.td:707)
    ve_vl_vfnmadd_vvvvmvl,                     // llvm.ve.vl.vfnmadd.vvvvmvl (IntrinsicsVEVL.gen.td:713)
    ve_vl_vfnmadd_vvvvvl,                      // llvm.ve.vl.vfnmadd.vvvvvl (IntrinsicsVEVL.gen.td:708)
    ve_vl_vfnmads_vsvvl,                       // llvm.ve.vl.vfnmads.vsvvl (IntrinsicsVEVL.gen.td:718)
    ve_vl_vfnmads_vsvvmvl,                     // llvm.ve.vl.vfnmads.vsvvmvl (IntrinsicsVEVL.gen.td:723)
    ve_vl_vfnmads_vsvvvl,                      // llvm.ve.vl.vfnmads.vsvvvl (IntrinsicsVEVL.gen.td:719)
    ve_vl_vfnmads_vvsvl,                       // llvm.ve.vl.vfnmads.vvsvl (IntrinsicsVEVL.gen.td:720)
    ve_vl_vfnmads_vvsvmvl,                     // llvm.ve.vl.vfnmads.vvsvmvl (IntrinsicsVEVL.gen.td:724)
    ve_vl_vfnmads_vvsvvl,                      // llvm.ve.vl.vfnmads.vvsvvl (IntrinsicsVEVL.gen.td:721)
    ve_vl_vfnmads_vvvvl,                       // llvm.ve.vl.vfnmads.vvvvl (IntrinsicsVEVL.gen.td:716)
    ve_vl_vfnmads_vvvvmvl,                     // llvm.ve.vl.vfnmads.vvvvmvl (IntrinsicsVEVL.gen.td:722)
    ve_vl_vfnmads_vvvvvl,                      // llvm.ve.vl.vfnmads.vvvvvl (IntrinsicsVEVL.gen.td:717)
    ve_vl_vfnmsbd_vsvvl,                       // llvm.ve.vl.vfnmsbd.vsvvl (IntrinsicsVEVL.gen.td:736)
    ve_vl_vfnmsbd_vsvvmvl,                     // llvm.ve.vl.vfnmsbd.vsvvmvl (IntrinsicsVEVL.gen.td:741)
    ve_vl_vfnmsbd_vsvvvl,                      // llvm.ve.vl.vfnmsbd.vsvvvl (IntrinsicsVEVL.gen.td:737)
    ve_vl_vfnmsbd_vvsvl,                       // llvm.ve.vl.vfnmsbd.vvsvl (IntrinsicsVEVL.gen.td:738)
    ve_vl_vfnmsbd_vvsvmvl,                     // llvm.ve.vl.vfnmsbd.vvsvmvl (IntrinsicsVEVL.gen.td:742)
    ve_vl_vfnmsbd_vvsvvl,                      // llvm.ve.vl.vfnmsbd.vvsvvl (IntrinsicsVEVL.gen.td:739)
    ve_vl_vfnmsbd_vvvvl,                       // llvm.ve.vl.vfnmsbd.vvvvl (IntrinsicsVEVL.gen.td:734)
    ve_vl_vfnmsbd_vvvvmvl,                     // llvm.ve.vl.vfnmsbd.vvvvmvl (IntrinsicsVEVL.gen.td:740)
    ve_vl_vfnmsbd_vvvvvl,                      // llvm.ve.vl.vfnmsbd.vvvvvl (IntrinsicsVEVL.gen.td:735)
    ve_vl_vfnmsbs_vsvvl,                       // llvm.ve.vl.vfnmsbs.vsvvl (IntrinsicsVEVL.gen.td:745)
    ve_vl_vfnmsbs_vsvvmvl,                     // llvm.ve.vl.vfnmsbs.vsvvmvl (IntrinsicsVEVL.gen.td:750)
    ve_vl_vfnmsbs_vsvvvl,                      // llvm.ve.vl.vfnmsbs.vsvvvl (IntrinsicsVEVL.gen.td:746)
    ve_vl_vfnmsbs_vvsvl,                       // llvm.ve.vl.vfnmsbs.vvsvl (IntrinsicsVEVL.gen.td:747)
    ve_vl_vfnmsbs_vvsvmvl,                     // llvm.ve.vl.vfnmsbs.vvsvmvl (IntrinsicsVEVL.gen.td:751)
    ve_vl_vfnmsbs_vvsvvl,                      // llvm.ve.vl.vfnmsbs.vvsvvl (IntrinsicsVEVL.gen.td:748)
    ve_vl_vfnmsbs_vvvvl,                       // llvm.ve.vl.vfnmsbs.vvvvl (IntrinsicsVEVL.gen.td:743)
    ve_vl_vfnmsbs_vvvvmvl,                     // llvm.ve.vl.vfnmsbs.vvvvmvl (IntrinsicsVEVL.gen.td:749)
    ve_vl_vfnmsbs_vvvvvl,                      // llvm.ve.vl.vfnmsbs.vvvvvl (IntrinsicsVEVL.gen.td:744)
    ve_vl_vfrmaxdfst_vvl,                      // llvm.ve.vl.vfrmaxdfst.vvl (IntrinsicsVEVL.gen.td:1157)
    ve_vl_vfrmaxdfst_vvvl,                     // llvm.ve.vl.vfrmaxdfst.vvvl (IntrinsicsVEVL.gen.td:1158)
    ve_vl_vfrmaxdlst_vvl,                      // llvm.ve.vl.vfrmaxdlst.vvl (IntrinsicsVEVL.gen.td:1159)
    ve_vl_vfrmaxdlst_vvvl,                     // llvm.ve.vl.vfrmaxdlst.vvvl (IntrinsicsVEVL.gen.td:1160)
    ve_vl_vfrmaxsfst_vvl,                      // llvm.ve.vl.vfrmaxsfst.vvl (IntrinsicsVEVL.gen.td:1161)
    ve_vl_vfrmaxsfst_vvvl,                     // llvm.ve.vl.vfrmaxsfst.vvvl (IntrinsicsVEVL.gen.td:1162)
    ve_vl_vfrmaxslst_vvl,                      // llvm.ve.vl.vfrmaxslst.vvl (IntrinsicsVEVL.gen.td:1163)
    ve_vl_vfrmaxslst_vvvl,                     // llvm.ve.vl.vfrmaxslst.vvvl (IntrinsicsVEVL.gen.td:1164)
    ve_vl_vfrmindfst_vvl,                      // llvm.ve.vl.vfrmindfst.vvl (IntrinsicsVEVL.gen.td:1165)
    ve_vl_vfrmindfst_vvvl,                     // llvm.ve.vl.vfrmindfst.vvvl (IntrinsicsVEVL.gen.td:1166)
    ve_vl_vfrmindlst_vvl,                      // llvm.ve.vl.vfrmindlst.vvl (IntrinsicsVEVL.gen.td:1167)
    ve_vl_vfrmindlst_vvvl,                     // llvm.ve.vl.vfrmindlst.vvvl (IntrinsicsVEVL.gen.td:1168)
    ve_vl_vfrminsfst_vvl,                      // llvm.ve.vl.vfrminsfst.vvl (IntrinsicsVEVL.gen.td:1169)
    ve_vl_vfrminsfst_vvvl,                     // llvm.ve.vl.vfrminsfst.vvvl (IntrinsicsVEVL.gen.td:1170)
    ve_vl_vfrminslst_vvl,                      // llvm.ve.vl.vfrminslst.vvl (IntrinsicsVEVL.gen.td:1171)
    ve_vl_vfrminslst_vvvl,                     // llvm.ve.vl.vfrminslst.vvvl (IntrinsicsVEVL.gen.td:1172)
    ve_vl_vfsqrtd_vvl,                         // llvm.ve.vl.vfsqrtd.vvl (IntrinsicsVEVL.gen.td:595)
    ve_vl_vfsqrtd_vvvl,                        // llvm.ve.vl.vfsqrtd.vvvl (IntrinsicsVEVL.gen.td:596)
    ve_vl_vfsqrts_vvl,                         // llvm.ve.vl.vfsqrts.vvl (IntrinsicsVEVL.gen.td:597)
    ve_vl_vfsqrts_vvvl,                        // llvm.ve.vl.vfsqrts.vvvl (IntrinsicsVEVL.gen.td:598)
    ve_vl_vfsubd_vsvl,                         // llvm.ve.vl.vfsubd.vsvl (IntrinsicsVEVL.gen.td:549)
    ve_vl_vfsubd_vsvmvl,                       // llvm.ve.vl.vfsubd.vsvmvl (IntrinsicsVEVL.gen.td:552)
    ve_vl_vfsubd_vsvvl,                        // llvm.ve.vl.vfsubd.vsvvl (IntrinsicsVEVL.gen.td:550)
    ve_vl_vfsubd_vvvl,                         // llvm.ve.vl.vfsubd.vvvl (IntrinsicsVEVL.gen.td:547)
    ve_vl_vfsubd_vvvmvl,                       // llvm.ve.vl.vfsubd.vvvmvl (IntrinsicsVEVL.gen.td:551)
    ve_vl_vfsubd_vvvvl,                        // llvm.ve.vl.vfsubd.vvvvl (IntrinsicsVEVL.gen.td:548)
    ve_vl_vfsubs_vsvl,                         // llvm.ve.vl.vfsubs.vsvl (IntrinsicsVEVL.gen.td:555)
    ve_vl_vfsubs_vsvmvl,                       // llvm.ve.vl.vfsubs.vsvmvl (IntrinsicsVEVL.gen.td:558)
    ve_vl_vfsubs_vsvvl,                        // llvm.ve.vl.vfsubs.vsvvl (IntrinsicsVEVL.gen.td:556)
    ve_vl_vfsubs_vvvl,                         // llvm.ve.vl.vfsubs.vvvl (IntrinsicsVEVL.gen.td:553)
    ve_vl_vfsubs_vvvmvl,                       // llvm.ve.vl.vfsubs.vvvmvl (IntrinsicsVEVL.gen.td:557)
    ve_vl_vfsubs_vvvvl,                        // llvm.ve.vl.vfsubs.vvvvl (IntrinsicsVEVL.gen.td:554)
    ve_vl_vfsumd_vvl,                          // llvm.ve.vl.vfsumd.vvl (IntrinsicsVEVL.gen.td:1129)
    ve_vl_vfsumd_vvml,                         // llvm.ve.vl.vfsumd.vvml (IntrinsicsVEVL.gen.td:1130)
    ve_vl_vfsums_vvl,                          // llvm.ve.vl.vfsums.vvl (IntrinsicsVEVL.gen.td:1131)
    ve_vl_vfsums_vvml,                         // llvm.ve.vl.vfsums.vvml (IntrinsicsVEVL.gen.td:1132)
    ve_vl_vgt_vvssl,                           // llvm.ve.vl.vgt.vvssl (IntrinsicsVEVL.gen.td:1179)
    ve_vl_vgt_vvssml,                          // llvm.ve.vl.vgt.vvssml (IntrinsicsVEVL.gen.td:1181)
    ve_vl_vgt_vvssmvl,                         // llvm.ve.vl.vgt.vvssmvl (IntrinsicsVEVL.gen.td:1182)
    ve_vl_vgt_vvssvl,                          // llvm.ve.vl.vgt.vvssvl (IntrinsicsVEVL.gen.td:1180)
    ve_vl_vgtlsx_vvssl,                        // llvm.ve.vl.vgtlsx.vvssl (IntrinsicsVEVL.gen.td:1195)
    ve_vl_vgtlsx_vvssml,                       // llvm.ve.vl.vgtlsx.vvssml (IntrinsicsVEVL.gen.td:1197)
    ve_vl_vgtlsx_vvssmvl,                      // llvm.ve.vl.vgtlsx.vvssmvl (IntrinsicsVEVL.gen.td:1198)
    ve_vl_vgtlsx_vvssvl,                       // llvm.ve.vl.vgtlsx.vvssvl (IntrinsicsVEVL.gen.td:1196)
    ve_vl_vgtlsxnc_vvssl,                      // llvm.ve.vl.vgtlsxnc.vvssl (IntrinsicsVEVL.gen.td:1199)
    ve_vl_vgtlsxnc_vvssml,                     // llvm.ve.vl.vgtlsxnc.vvssml (IntrinsicsVEVL.gen.td:1201)
    ve_vl_vgtlsxnc_vvssmvl,                    // llvm.ve.vl.vgtlsxnc.vvssmvl (IntrinsicsVEVL.gen.td:1202)
    ve_vl_vgtlsxnc_vvssvl,                     // llvm.ve.vl.vgtlsxnc.vvssvl (IntrinsicsVEVL.gen.td:1200)
    ve_vl_vgtlzx_vvssl,                        // llvm.ve.vl.vgtlzx.vvssl (IntrinsicsVEVL.gen.td:1203)
    ve_vl_vgtlzx_vvssml,                       // llvm.ve.vl.vgtlzx.vvssml (IntrinsicsVEVL.gen.td:1205)
    ve_vl_vgtlzx_vvssmvl,                      // llvm.ve.vl.vgtlzx.vvssmvl (IntrinsicsVEVL.gen.td:1206)
    ve_vl_vgtlzx_vvssvl,                       // llvm.ve.vl.vgtlzx.vvssvl (IntrinsicsVEVL.gen.td:1204)
    ve_vl_vgtlzxnc_vvssl,                      // llvm.ve.vl.vgtlzxnc.vvssl (IntrinsicsVEVL.gen.td:1207)
    ve_vl_vgtlzxnc_vvssml,                     // llvm.ve.vl.vgtlzxnc.vvssml (IntrinsicsVEVL.gen.td:1209)
    ve_vl_vgtlzxnc_vvssmvl,                    // llvm.ve.vl.vgtlzxnc.vvssmvl (IntrinsicsVEVL.gen.td:1210)
    ve_vl_vgtlzxnc_vvssvl,                     // llvm.ve.vl.vgtlzxnc.vvssvl (IntrinsicsVEVL.gen.td:1208)
    ve_vl_vgtnc_vvssl,                         // llvm.ve.vl.vgtnc.vvssl (IntrinsicsVEVL.gen.td:1183)
    ve_vl_vgtnc_vvssml,                        // llvm.ve.vl.vgtnc.vvssml (IntrinsicsVEVL.gen.td:1185)
    ve_vl_vgtnc_vvssmvl,                       // llvm.ve.vl.vgtnc.vvssmvl (IntrinsicsVEVL.gen.td:1186)
    ve_vl_vgtnc_vvssvl,                        // llvm.ve.vl.vgtnc.vvssvl (IntrinsicsVEVL.gen.td:1184)
    ve_vl_vgtu_vvssl,                          // llvm.ve.vl.vgtu.vvssl (IntrinsicsVEVL.gen.td:1187)
    ve_vl_vgtu_vvssml,                         // llvm.ve.vl.vgtu.vvssml (IntrinsicsVEVL.gen.td:1189)
    ve_vl_vgtu_vvssmvl,                        // llvm.ve.vl.vgtu.vvssmvl (IntrinsicsVEVL.gen.td:1190)
    ve_vl_vgtu_vvssvl,                         // llvm.ve.vl.vgtu.vvssvl (IntrinsicsVEVL.gen.td:1188)
    ve_vl_vgtunc_vvssl,                        // llvm.ve.vl.vgtunc.vvssl (IntrinsicsVEVL.gen.td:1191)
    ve_vl_vgtunc_vvssml,                       // llvm.ve.vl.vgtunc.vvssml (IntrinsicsVEVL.gen.td:1193)
    ve_vl_vgtunc_vvssmvl,                      // llvm.ve.vl.vgtunc.vvssmvl (IntrinsicsVEVL.gen.td:1194)
    ve_vl_vgtunc_vvssvl,                       // llvm.ve.vl.vgtunc.vvssvl (IntrinsicsVEVL.gen.td:1192)
    ve_vl_vld_vssl,                            // llvm.ve.vl.vld.vssl (IntrinsicsVEVL.gen.td:1)
    ve_vl_vld_vssvl,                           // llvm.ve.vl.vld.vssvl (IntrinsicsVEVL.gen.td:2)
    ve_vl_vld2d_vssl,                          // llvm.ve.vl.vld2d.vssl (IntrinsicsVEVL.gen.td:17)
    ve_vl_vld2d_vssvl,                         // llvm.ve.vl.vld2d.vssvl (IntrinsicsVEVL.gen.td:18)
    ve_vl_vld2dnc_vssl,                        // llvm.ve.vl.vld2dnc.vssl (IntrinsicsVEVL.gen.td:19)
    ve_vl_vld2dnc_vssvl,                       // llvm.ve.vl.vld2dnc.vssvl (IntrinsicsVEVL.gen.td:20)
    ve_vl_vldl2dsx_vssl,                       // llvm.ve.vl.vldl2dsx.vssl (IntrinsicsVEVL.gen.td:25)
    ve_vl_vldl2dsx_vssvl,                      // llvm.ve.vl.vldl2dsx.vssvl (IntrinsicsVEVL.gen.td:26)
    ve_vl_vldl2dsxnc_vssl,                     // llvm.ve.vl.vldl2dsxnc.vssl (IntrinsicsVEVL.gen.td:27)
    ve_vl_vldl2dsxnc_vssvl,                    // llvm.ve.vl.vldl2dsxnc.vssvl (IntrinsicsVEVL.gen.td:28)
    ve_vl_vldl2dzx_vssl,                       // llvm.ve.vl.vldl2dzx.vssl (IntrinsicsVEVL.gen.td:29)
    ve_vl_vldl2dzx_vssvl,                      // llvm.ve.vl.vldl2dzx.vssvl (IntrinsicsVEVL.gen.td:30)
    ve_vl_vldl2dzxnc_vssl,                     // llvm.ve.vl.vldl2dzxnc.vssl (IntrinsicsVEVL.gen.td:31)
    ve_vl_vldl2dzxnc_vssvl,                    // llvm.ve.vl.vldl2dzxnc.vssvl (IntrinsicsVEVL.gen.td:32)
    ve_vl_vldlsx_vssl,                         // llvm.ve.vl.vldlsx.vssl (IntrinsicsVEVL.gen.td:9)
    ve_vl_vldlsx_vssvl,                        // llvm.ve.vl.vldlsx.vssvl (IntrinsicsVEVL.gen.td:10)
    ve_vl_vldlsxnc_vssl,                       // llvm.ve.vl.vldlsxnc.vssl (IntrinsicsVEVL.gen.td:11)
    ve_vl_vldlsxnc_vssvl,                      // llvm.ve.vl.vldlsxnc.vssvl (IntrinsicsVEVL.gen.td:12)
    ve_vl_vldlzx_vssl,                         // llvm.ve.vl.vldlzx.vssl (IntrinsicsVEVL.gen.td:13)
    ve_vl_vldlzx_vssvl,                        // llvm.ve.vl.vldlzx.vssvl (IntrinsicsVEVL.gen.td:14)
    ve_vl_vldlzxnc_vssl,                       // llvm.ve.vl.vldlzxnc.vssl (IntrinsicsVEVL.gen.td:15)
    ve_vl_vldlzxnc_vssvl,                      // llvm.ve.vl.vldlzxnc.vssvl (IntrinsicsVEVL.gen.td:16)
    ve_vl_vldnc_vssl,                          // llvm.ve.vl.vldnc.vssl (IntrinsicsVEVL.gen.td:3)
    ve_vl_vldnc_vssvl,                         // llvm.ve.vl.vldnc.vssvl (IntrinsicsVEVL.gen.td:4)
    ve_vl_vldu_vssl,                           // llvm.ve.vl.vldu.vssl (IntrinsicsVEVL.gen.td:5)
    ve_vl_vldu_vssvl,                          // llvm.ve.vl.vldu.vssvl (IntrinsicsVEVL.gen.td:6)
    ve_vl_vldu2d_vssl,                         // llvm.ve.vl.vldu2d.vssl (IntrinsicsVEVL.gen.td:21)
    ve_vl_vldu2d_vssvl,                        // llvm.ve.vl.vldu2d.vssvl (IntrinsicsVEVL.gen.td:22)
    ve_vl_vldu2dnc_vssl,                       // llvm.ve.vl.vldu2dnc.vssl (IntrinsicsVEVL.gen.td:23)
    ve_vl_vldu2dnc_vssvl,                      // llvm.ve.vl.vldu2dnc.vssvl (IntrinsicsVEVL.gen.td:24)
    ve_vl_vldunc_vssl,                         // llvm.ve.vl.vldunc.vssl (IntrinsicsVEVL.gen.td:7)
    ve_vl_vldunc_vssvl,                        // llvm.ve.vl.vldunc.vssvl (IntrinsicsVEVL.gen.td:8)
    ve_vl_vldz_vvl,                            // llvm.ve.vl.vldz.vvl (IntrinsicsVEVL.gen.td:410)
    ve_vl_vldz_vvmvl,                          // llvm.ve.vl.vldz.vvmvl (IntrinsicsVEVL.gen.td:412)
    ve_vl_vldz_vvvl,                           // llvm.ve.vl.vldz.vvvl (IntrinsicsVEVL.gen.td:411)
    ve_vl_vmaxsl_vsvl,                         // llvm.ve.vl.vmaxsl.vsvl (IntrinsicsVEVL.gen.td:352)
    ve_vl_vmaxsl_vsvmvl,                       // llvm.ve.vl.vmaxsl.vsvmvl (IntrinsicsVEVL.gen.td:355)
    ve_vl_vmaxsl_vsvvl,                        // llvm.ve.vl.vmaxsl.vsvvl (IntrinsicsVEVL.gen.td:353)
    ve_vl_vmaxsl_vvvl,                         // llvm.ve.vl.vmaxsl.vvvl (IntrinsicsVEVL.gen.td:350)
    ve_vl_vmaxsl_vvvmvl,                       // llvm.ve.vl.vmaxsl.vvvmvl (IntrinsicsVEVL.gen.td:354)
    ve_vl_vmaxsl_vvvvl,                        // llvm.ve.vl.vmaxsl.vvvvl (IntrinsicsVEVL.gen.td:351)
    ve_vl_vmaxswsx_vsvl,                       // llvm.ve.vl.vmaxswsx.vsvl (IntrinsicsVEVL.gen.td:316)
    ve_vl_vmaxswsx_vsvmvl,                     // llvm.ve.vl.vmaxswsx.vsvmvl (IntrinsicsVEVL.gen.td:319)
    ve_vl_vmaxswsx_vsvvl,                      // llvm.ve.vl.vmaxswsx.vsvvl (IntrinsicsVEVL.gen.td:317)
    ve_vl_vmaxswsx_vvvl,                       // llvm.ve.vl.vmaxswsx.vvvl (IntrinsicsVEVL.gen.td:314)
    ve_vl_vmaxswsx_vvvmvl,                     // llvm.ve.vl.vmaxswsx.vvvmvl (IntrinsicsVEVL.gen.td:318)
    ve_vl_vmaxswsx_vvvvl,                      // llvm.ve.vl.vmaxswsx.vvvvl (IntrinsicsVEVL.gen.td:315)
    ve_vl_vmaxswzx_vsvl,                       // llvm.ve.vl.vmaxswzx.vsvl (IntrinsicsVEVL.gen.td:322)
    ve_vl_vmaxswzx_vsvmvl,                     // llvm.ve.vl.vmaxswzx.vsvmvl (IntrinsicsVEVL.gen.td:325)
    ve_vl_vmaxswzx_vsvvl,                      // llvm.ve.vl.vmaxswzx.vsvvl (IntrinsicsVEVL.gen.td:323)
    ve_vl_vmaxswzx_vvvl,                       // llvm.ve.vl.vmaxswzx.vvvl (IntrinsicsVEVL.gen.td:320)
    ve_vl_vmaxswzx_vvvmvl,                     // llvm.ve.vl.vmaxswzx.vvvmvl (IntrinsicsVEVL.gen.td:324)
    ve_vl_vmaxswzx_vvvvl,                      // llvm.ve.vl.vmaxswzx.vvvvl (IntrinsicsVEVL.gen.td:321)
    ve_vl_vminsl_vsvl,                         // llvm.ve.vl.vminsl.vsvl (IntrinsicsVEVL.gen.td:358)
    ve_vl_vminsl_vsvmvl,                       // llvm.ve.vl.vminsl.vsvmvl (IntrinsicsVEVL.gen.td:361)
    ve_vl_vminsl_vsvvl,                        // llvm.ve.vl.vminsl.vsvvl (IntrinsicsVEVL.gen.td:359)
    ve_vl_vminsl_vvvl,                         // llvm.ve.vl.vminsl.vvvl (IntrinsicsVEVL.gen.td:356)
    ve_vl_vminsl_vvvmvl,                       // llvm.ve.vl.vminsl.vvvmvl (IntrinsicsVEVL.gen.td:360)
    ve_vl_vminsl_vvvvl,                        // llvm.ve.vl.vminsl.vvvvl (IntrinsicsVEVL.gen.td:357)
    ve_vl_vminswsx_vsvl,                       // llvm.ve.vl.vminswsx.vsvl (IntrinsicsVEVL.gen.td:334)
    ve_vl_vminswsx_vsvmvl,                     // llvm.ve.vl.vminswsx.vsvmvl (IntrinsicsVEVL.gen.td:337)
    ve_vl_vminswsx_vsvvl,                      // llvm.ve.vl.vminswsx.vsvvl (IntrinsicsVEVL.gen.td:335)
    ve_vl_vminswsx_vvvl,                       // llvm.ve.vl.vminswsx.vvvl (IntrinsicsVEVL.gen.td:332)
    ve_vl_vminswsx_vvvmvl,                     // llvm.ve.vl.vminswsx.vvvmvl (IntrinsicsVEVL.gen.td:336)
    ve_vl_vminswsx_vvvvl,                      // llvm.ve.vl.vminswsx.vvvvl (IntrinsicsVEVL.gen.td:333)
    ve_vl_vminswzx_vsvl,                       // llvm.ve.vl.vminswzx.vsvl (IntrinsicsVEVL.gen.td:340)
    ve_vl_vminswzx_vsvmvl,                     // llvm.ve.vl.vminswzx.vsvmvl (IntrinsicsVEVL.gen.td:343)
    ve_vl_vminswzx_vsvvl,                      // llvm.ve.vl.vminswzx.vsvvl (IntrinsicsVEVL.gen.td:341)
    ve_vl_vminswzx_vvvl,                       // llvm.ve.vl.vminswzx.vvvl (IntrinsicsVEVL.gen.td:338)
    ve_vl_vminswzx_vvvmvl,                     // llvm.ve.vl.vminswzx.vvvmvl (IntrinsicsVEVL.gen.td:342)
    ve_vl_vminswzx_vvvvl,                      // llvm.ve.vl.vminswzx.vvvvl (IntrinsicsVEVL.gen.td:339)
    ve_vl_vmrg_vsvml,                          // llvm.ve.vl.vmrg.vsvml (IntrinsicsVEVL.gen.td:829)
    ve_vl_vmrg_vsvmvl,                         // llvm.ve.vl.vmrg.vsvmvl (IntrinsicsVEVL.gen.td:830)
    ve_vl_vmrg_vvvml,                          // llvm.ve.vl.vmrg.vvvml (IntrinsicsVEVL.gen.td:827)
    ve_vl_vmrg_vvvmvl,                         // llvm.ve.vl.vmrg.vvvmvl (IntrinsicsVEVL.gen.td:828)
    ve_vl_vmrgw_vsvMl,                         // llvm.ve.vl.vmrgw.vsvMl (IntrinsicsVEVL.gen.td:833)
    ve_vl_vmrgw_vsvMvl,                        // llvm.ve.vl.vmrgw.vsvMvl (IntrinsicsVEVL.gen.td:834)
    ve_vl_vmrgw_vvvMl,                         // llvm.ve.vl.vmrgw.vvvMl (IntrinsicsVEVL.gen.td:831)
    ve_vl_vmrgw_vvvMvl,                        // llvm.ve.vl.vmrgw.vvvMvl (IntrinsicsVEVL.gen.td:832)
    ve_vl_vmulsl_vsvl,                         // llvm.ve.vl.vmulsl.vsvl (IntrinsicsVEVL.gen.td:219)
    ve_vl_vmulsl_vsvmvl,                       // llvm.ve.vl.vmulsl.vsvmvl (IntrinsicsVEVL.gen.td:222)
    ve_vl_vmulsl_vsvvl,                        // llvm.ve.vl.vmulsl.vsvvl (IntrinsicsVEVL.gen.td:220)
    ve_vl_vmulsl_vvvl,                         // llvm.ve.vl.vmulsl.vvvl (IntrinsicsVEVL.gen.td:217)
    ve_vl_vmulsl_vvvmvl,                       // llvm.ve.vl.vmulsl.vvvmvl (IntrinsicsVEVL.gen.td:221)
    ve_vl_vmulsl_vvvvl,                        // llvm.ve.vl.vmulsl.vvvvl (IntrinsicsVEVL.gen.td:218)
    ve_vl_vmulslw_vsvl,                        // llvm.ve.vl.vmulslw.vsvl (IntrinsicsVEVL.gen.td:225)
    ve_vl_vmulslw_vsvvl,                       // llvm.ve.vl.vmulslw.vsvvl (IntrinsicsVEVL.gen.td:226)
    ve_vl_vmulslw_vvvl,                        // llvm.ve.vl.vmulslw.vvvl (IntrinsicsVEVL.gen.td:223)
    ve_vl_vmulslw_vvvvl,                       // llvm.ve.vl.vmulslw.vvvvl (IntrinsicsVEVL.gen.td:224)
    ve_vl_vmulswsx_vsvl,                       // llvm.ve.vl.vmulswsx.vsvl (IntrinsicsVEVL.gen.td:207)
    ve_vl_vmulswsx_vsvmvl,                     // llvm.ve.vl.vmulswsx.vsvmvl (IntrinsicsVEVL.gen.td:210)
    ve_vl_vmulswsx_vsvvl,                      // llvm.ve.vl.vmulswsx.vsvvl (IntrinsicsVEVL.gen.td:208)
    ve_vl_vmulswsx_vvvl,                       // llvm.ve.vl.vmulswsx.vvvl (IntrinsicsVEVL.gen.td:205)
    ve_vl_vmulswsx_vvvmvl,                     // llvm.ve.vl.vmulswsx.vvvmvl (IntrinsicsVEVL.gen.td:209)
    ve_vl_vmulswsx_vvvvl,                      // llvm.ve.vl.vmulswsx.vvvvl (IntrinsicsVEVL.gen.td:206)
    ve_vl_vmulswzx_vsvl,                       // llvm.ve.vl.vmulswzx.vsvl (IntrinsicsVEVL.gen.td:213)
    ve_vl_vmulswzx_vsvmvl,                     // llvm.ve.vl.vmulswzx.vsvmvl (IntrinsicsVEVL.gen.td:216)
    ve_vl_vmulswzx_vsvvl,                      // llvm.ve.vl.vmulswzx.vsvvl (IntrinsicsVEVL.gen.td:214)
    ve_vl_vmulswzx_vvvl,                       // llvm.ve.vl.vmulswzx.vvvl (IntrinsicsVEVL.gen.td:211)
    ve_vl_vmulswzx_vvvmvl,                     // llvm.ve.vl.vmulswzx.vvvmvl (IntrinsicsVEVL.gen.td:215)
    ve_vl_vmulswzx_vvvvl,                      // llvm.ve.vl.vmulswzx.vvvvl (IntrinsicsVEVL.gen.td:212)
    ve_vl_vmulul_vsvl,                         // llvm.ve.vl.vmulul.vsvl (IntrinsicsVEVL.gen.td:195)
    ve_vl_vmulul_vsvmvl,                       // llvm.ve.vl.vmulul.vsvmvl (IntrinsicsVEVL.gen.td:198)
    ve_vl_vmulul_vsvvl,                        // llvm.ve.vl.vmulul.vsvvl (IntrinsicsVEVL.gen.td:196)
    ve_vl_vmulul_vvvl,                         // llvm.ve.vl.vmulul.vvvl (IntrinsicsVEVL.gen.td:193)
    ve_vl_vmulul_vvvmvl,                       // llvm.ve.vl.vmulul.vvvmvl (IntrinsicsVEVL.gen.td:197)
    ve_vl_vmulul_vvvvl,                        // llvm.ve.vl.vmulul.vvvvl (IntrinsicsVEVL.gen.td:194)
    ve_vl_vmuluw_vsvl,                         // llvm.ve.vl.vmuluw.vsvl (IntrinsicsVEVL.gen.td:201)
    ve_vl_vmuluw_vsvmvl,                       // llvm.ve.vl.vmuluw.vsvmvl (IntrinsicsVEVL.gen.td:204)
    ve_vl_vmuluw_vsvvl,                        // llvm.ve.vl.vmuluw.vsvvl (IntrinsicsVEVL.gen.td:202)
    ve_vl_vmuluw_vvvl,                         // llvm.ve.vl.vmuluw.vvvl (IntrinsicsVEVL.gen.td:199)
    ve_vl_vmuluw_vvvmvl,                       // llvm.ve.vl.vmuluw.vvvmvl (IntrinsicsVEVL.gen.td:203)
    ve_vl_vmuluw_vvvvl,                        // llvm.ve.vl.vmuluw.vvvvl (IntrinsicsVEVL.gen.td:200)
    ve_vl_vmv_vsvl,                            // llvm.ve.vl.vmv.vsvl (IntrinsicsVEVL.gen.td:106)
    ve_vl_vmv_vsvmvl,                          // llvm.ve.vl.vmv.vsvmvl (IntrinsicsVEVL.gen.td:108)
    ve_vl_vmv_vsvvl,                           // llvm.ve.vl.vmv.vsvvl (IntrinsicsVEVL.gen.td:107)
    ve_vl_vor_vsvl,                            // llvm.ve.vl.vor.vsvl (IntrinsicsVEVL.gen.td:376)
    ve_vl_vor_vsvmvl,                          // llvm.ve.vl.vor.vsvmvl (IntrinsicsVEVL.gen.td:379)
    ve_vl_vor_vsvvl,                           // llvm.ve.vl.vor.vsvvl (IntrinsicsVEVL.gen.td:377)
    ve_vl_vor_vvvl,                            // llvm.ve.vl.vor.vvvl (IntrinsicsVEVL.gen.td:374)
    ve_vl_vor_vvvmvl,                          // llvm.ve.vl.vor.vvvmvl (IntrinsicsVEVL.gen.td:378)
    ve_vl_vor_vvvvl,                           // llvm.ve.vl.vor.vvvvl (IntrinsicsVEVL.gen.td:375)
    ve_vl_vpcnt_vvl,                           // llvm.ve.vl.vpcnt.vvl (IntrinsicsVEVL.gen.td:422)
    ve_vl_vpcnt_vvmvl,                         // llvm.ve.vl.vpcnt.vvmvl (IntrinsicsVEVL.gen.td:424)
    ve_vl_vpcnt_vvvl,                          // llvm.ve.vl.vpcnt.vvvl (IntrinsicsVEVL.gen.td:423)
    ve_vl_vrand_vvl,                           // llvm.ve.vl.vrand.vvl (IntrinsicsVEVL.gen.td:1173)
    ve_vl_vrand_vvml,                          // llvm.ve.vl.vrand.vvml (IntrinsicsVEVL.gen.td:1174)
    ve_vl_vrcpd_vvl,                           // llvm.ve.vl.vrcpd.vvl (IntrinsicsVEVL.gen.td:761)
    ve_vl_vrcpd_vvvl,                          // llvm.ve.vl.vrcpd.vvvl (IntrinsicsVEVL.gen.td:762)
    ve_vl_vrcps_vvl,                           // llvm.ve.vl.vrcps.vvl (IntrinsicsVEVL.gen.td:763)
    ve_vl_vrcps_vvvl,                          // llvm.ve.vl.vrcps.vvvl (IntrinsicsVEVL.gen.td:764)
    ve_vl_vrmaxslfst_vvl,                      // llvm.ve.vl.vrmaxslfst.vvl (IntrinsicsVEVL.gen.td:1149)
    ve_vl_vrmaxslfst_vvvl,                     // llvm.ve.vl.vrmaxslfst.vvvl (IntrinsicsVEVL.gen.td:1150)
    ve_vl_vrmaxsllst_vvl,                      // llvm.ve.vl.vrmaxsllst.vvl (IntrinsicsVEVL.gen.td:1151)
    ve_vl_vrmaxsllst_vvvl,                     // llvm.ve.vl.vrmaxsllst.vvvl (IntrinsicsVEVL.gen.td:1152)
    ve_vl_vrmaxswfstsx_vvl,                    // llvm.ve.vl.vrmaxswfstsx.vvl (IntrinsicsVEVL.gen.td:1133)
    ve_vl_vrmaxswfstsx_vvvl,                   // llvm.ve.vl.vrmaxswfstsx.vvvl (IntrinsicsVEVL.gen.td:1134)
    ve_vl_vrmaxswfstzx_vvl,                    // llvm.ve.vl.vrmaxswfstzx.vvl (IntrinsicsVEVL.gen.td:1137)
    ve_vl_vrmaxswfstzx_vvvl,                   // llvm.ve.vl.vrmaxswfstzx.vvvl (IntrinsicsVEVL.gen.td:1138)
    ve_vl_vrmaxswlstsx_vvl,                    // llvm.ve.vl.vrmaxswlstsx.vvl (IntrinsicsVEVL.gen.td:1135)
    ve_vl_vrmaxswlstsx_vvvl,                   // llvm.ve.vl.vrmaxswlstsx.vvvl (IntrinsicsVEVL.gen.td:1136)
    ve_vl_vrmaxswlstzx_vvl,                    // llvm.ve.vl.vrmaxswlstzx.vvl (IntrinsicsVEVL.gen.td:1139)
    ve_vl_vrmaxswlstzx_vvvl,                   // llvm.ve.vl.vrmaxswlstzx.vvvl (IntrinsicsVEVL.gen.td:1140)
    ve_vl_vrminslfst_vvl,                      // llvm.ve.vl.vrminslfst.vvl (IntrinsicsVEVL.gen.td:1153)
    ve_vl_vrminslfst_vvvl,                     // llvm.ve.vl.vrminslfst.vvvl (IntrinsicsVEVL.gen.td:1154)
    ve_vl_vrminsllst_vvl,                      // llvm.ve.vl.vrminsllst.vvl (IntrinsicsVEVL.gen.td:1155)
    ve_vl_vrminsllst_vvvl,                     // llvm.ve.vl.vrminsllst.vvvl (IntrinsicsVEVL.gen.td:1156)
    ve_vl_vrminswfstsx_vvl,                    // llvm.ve.vl.vrminswfstsx.vvl (IntrinsicsVEVL.gen.td:1141)
    ve_vl_vrminswfstsx_vvvl,                   // llvm.ve.vl.vrminswfstsx.vvvl (IntrinsicsVEVL.gen.td:1142)
    ve_vl_vrminswfstzx_vvl,                    // llvm.ve.vl.vrminswfstzx.vvl (IntrinsicsVEVL.gen.td:1145)
    ve_vl_vrminswfstzx_vvvl,                   // llvm.ve.vl.vrminswfstzx.vvvl (IntrinsicsVEVL.gen.td:1146)
    ve_vl_vrminswlstsx_vvl,                    // llvm.ve.vl.vrminswlstsx.vvl (IntrinsicsVEVL.gen.td:1143)
    ve_vl_vrminswlstsx_vvvl,                   // llvm.ve.vl.vrminswlstsx.vvvl (IntrinsicsVEVL.gen.td:1144)
    ve_vl_vrminswlstzx_vvl,                    // llvm.ve.vl.vrminswlstzx.vvl (IntrinsicsVEVL.gen.td:1147)
    ve_vl_vrminswlstzx_vvvl,                   // llvm.ve.vl.vrminswlstzx.vvvl (IntrinsicsVEVL.gen.td:1148)
    ve_vl_vror_vvl,                            // llvm.ve.vl.vror.vvl (IntrinsicsVEVL.gen.td:1175)
    ve_vl_vror_vvml,                           // llvm.ve.vl.vror.vvml (IntrinsicsVEVL.gen.td:1176)
    ve_vl_vrsqrtd_vvl,                         // llvm.ve.vl.vrsqrtd.vvl (IntrinsicsVEVL.gen.td:767)
    ve_vl_vrsqrtd_vvvl,                        // llvm.ve.vl.vrsqrtd.vvvl (IntrinsicsVEVL.gen.td:768)
    ve_vl_vrsqrtdnex_vvl,                      // llvm.ve.vl.vrsqrtdnex.vvl (IntrinsicsVEVL.gen.td:773)
    ve_vl_vrsqrtdnex_vvvl,                     // llvm.ve.vl.vrsqrtdnex.vvvl (IntrinsicsVEVL.gen.td:774)
    ve_vl_vrsqrts_vvl,                         // llvm.ve.vl.vrsqrts.vvl (IntrinsicsVEVL.gen.td:769)
    ve_vl_vrsqrts_vvvl,                        // llvm.ve.vl.vrsqrts.vvvl (IntrinsicsVEVL.gen.td:770)
    ve_vl_vrsqrtsnex_vvl,                      // llvm.ve.vl.vrsqrtsnex.vvl (IntrinsicsVEVL.gen.td:775)
    ve_vl_vrsqrtsnex_vvvl,                     // llvm.ve.vl.vrsqrtsnex.vvvl (IntrinsicsVEVL.gen.td:776)
    ve_vl_vrxor_vvl,                           // llvm.ve.vl.vrxor.vvl (IntrinsicsVEVL.gen.td:1177)
    ve_vl_vrxor_vvml,                          // llvm.ve.vl.vrxor.vvml (IntrinsicsVEVL.gen.td:1178)
    ve_vl_vsc_vvssl,                           // llvm.ve.vl.vsc.vvssl (IntrinsicsVEVL.gen.td:1211)
    ve_vl_vsc_vvssml,                          // llvm.ve.vl.vsc.vvssml (IntrinsicsVEVL.gen.td:1212)
    ve_vl_vscl_vvssl,                          // llvm.ve.vl.vscl.vvssl (IntrinsicsVEVL.gen.td:1227)
    ve_vl_vscl_vvssml,                         // llvm.ve.vl.vscl.vvssml (IntrinsicsVEVL.gen.td:1228)
    ve_vl_vsclnc_vvssl,                        // llvm.ve.vl.vsclnc.vvssl (IntrinsicsVEVL.gen.td:1229)
    ve_vl_vsclnc_vvssml,                       // llvm.ve.vl.vsclnc.vvssml (IntrinsicsVEVL.gen.td:1230)
    ve_vl_vsclncot_vvssl,                      // llvm.ve.vl.vsclncot.vvssl (IntrinsicsVEVL.gen.td:1233)
    ve_vl_vsclncot_vvssml,                     // llvm.ve.vl.vsclncot.vvssml (IntrinsicsVEVL.gen.td:1234)
    ve_vl_vsclot_vvssl,                        // llvm.ve.vl.vsclot.vvssl (IntrinsicsVEVL.gen.td:1231)
    ve_vl_vsclot_vvssml,                       // llvm.ve.vl.vsclot.vvssml (IntrinsicsVEVL.gen.td:1232)
    ve_vl_vscnc_vvssl,                         // llvm.ve.vl.vscnc.vvssl (IntrinsicsVEVL.gen.td:1213)
    ve_vl_vscnc_vvssml,                        // llvm.ve.vl.vscnc.vvssml (IntrinsicsVEVL.gen.td:1214)
    ve_vl_vscncot_vvssl,                       // llvm.ve.vl.vscncot.vvssl (IntrinsicsVEVL.gen.td:1217)
    ve_vl_vscncot_vvssml,                      // llvm.ve.vl.vscncot.vvssml (IntrinsicsVEVL.gen.td:1218)
    ve_vl_vscot_vvssl,                         // llvm.ve.vl.vscot.vvssl (IntrinsicsVEVL.gen.td:1215)
    ve_vl_vscot_vvssml,                        // llvm.ve.vl.vscot.vvssml (IntrinsicsVEVL.gen.td:1216)
    ve_vl_vscu_vvssl,                          // llvm.ve.vl.vscu.vvssl (IntrinsicsVEVL.gen.td:1219)
    ve_vl_vscu_vvssml,                         // llvm.ve.vl.vscu.vvssml (IntrinsicsVEVL.gen.td:1220)
    ve_vl_vscunc_vvssl,                        // llvm.ve.vl.vscunc.vvssl (IntrinsicsVEVL.gen.td:1221)
    ve_vl_vscunc_vvssml,                       // llvm.ve.vl.vscunc.vvssml (IntrinsicsVEVL.gen.td:1222)
    ve_vl_vscuncot_vvssl,                      // llvm.ve.vl.vscuncot.vvssl (IntrinsicsVEVL.gen.td:1225)
    ve_vl_vscuncot_vvssml,                     // llvm.ve.vl.vscuncot.vvssml (IntrinsicsVEVL.gen.td:1226)
    ve_vl_vscuot_vvssl,                        // llvm.ve.vl.vscuot.vvssl (IntrinsicsVEVL.gen.td:1223)
    ve_vl_vscuot_vvssml,                       // llvm.ve.vl.vscuot.vvssml (IntrinsicsVEVL.gen.td:1224)
    ve_vl_vseq_vl,                             // llvm.ve.vl.vseq.vl (IntrinsicsVEVL.gen.td:446)
    ve_vl_vseq_vvl,                            // llvm.ve.vl.vseq.vvl (IntrinsicsVEVL.gen.td:447)
    ve_vl_vsfa_vvssl,                          // llvm.ve.vl.vsfa.vvssl (IntrinsicsVEVL.gen.td:526)
    ve_vl_vsfa_vvssmvl,                        // llvm.ve.vl.vsfa.vvssmvl (IntrinsicsVEVL.gen.td:528)
    ve_vl_vsfa_vvssvl,                         // llvm.ve.vl.vsfa.vvssvl (IntrinsicsVEVL.gen.td:527)
    ve_vl_vshf_vvvsl,                          // llvm.ve.vl.vshf.vvvsl (IntrinsicsVEVL.gen.td:835)
    ve_vl_vshf_vvvsvl,                         // llvm.ve.vl.vshf.vvvsvl (IntrinsicsVEVL.gen.td:836)
    ve_vl_vslal_vvsl,                          // llvm.ve.vl.vslal.vvsl (IntrinsicsVEVL.gen.td:498)
    ve_vl_vslal_vvsmvl,                        // llvm.ve.vl.vslal.vvsmvl (IntrinsicsVEVL.gen.td:501)
    ve_vl_vslal_vvsvl,                         // llvm.ve.vl.vslal.vvsvl (IntrinsicsVEVL.gen.td:499)
    ve_vl_vslal_vvvl,                          // llvm.ve.vl.vslal.vvvl (IntrinsicsVEVL.gen.td:496)
    ve_vl_vslal_vvvmvl,                        // llvm.ve.vl.vslal.vvvmvl (IntrinsicsVEVL.gen.td:500)
    ve_vl_vslal_vvvvl,                         // llvm.ve.vl.vslal.vvvvl (IntrinsicsVEVL.gen.td:497)
    ve_vl_vslawsx_vvsl,                        // llvm.ve.vl.vslawsx.vvsl (IntrinsicsVEVL.gen.td:480)
    ve_vl_vslawsx_vvsmvl,                      // llvm.ve.vl.vslawsx.vvsmvl (IntrinsicsVEVL.gen.td:483)
    ve_vl_vslawsx_vvsvl,                       // llvm.ve.vl.vslawsx.vvsvl (IntrinsicsVEVL.gen.td:481)
    ve_vl_vslawsx_vvvl,                        // llvm.ve.vl.vslawsx.vvvl (IntrinsicsVEVL.gen.td:478)
    ve_vl_vslawsx_vvvmvl,                      // llvm.ve.vl.vslawsx.vvvmvl (IntrinsicsVEVL.gen.td:482)
    ve_vl_vslawsx_vvvvl,                       // llvm.ve.vl.vslawsx.vvvvl (IntrinsicsVEVL.gen.td:479)
    ve_vl_vslawzx_vvsl,                        // llvm.ve.vl.vslawzx.vvsl (IntrinsicsVEVL.gen.td:486)
    ve_vl_vslawzx_vvsmvl,                      // llvm.ve.vl.vslawzx.vvsmvl (IntrinsicsVEVL.gen.td:489)
    ve_vl_vslawzx_vvsvl,                       // llvm.ve.vl.vslawzx.vvsvl (IntrinsicsVEVL.gen.td:487)
    ve_vl_vslawzx_vvvl,                        // llvm.ve.vl.vslawzx.vvvl (IntrinsicsVEVL.gen.td:484)
    ve_vl_vslawzx_vvvmvl,                      // llvm.ve.vl.vslawzx.vvvmvl (IntrinsicsVEVL.gen.td:488)
    ve_vl_vslawzx_vvvvl,                       // llvm.ve.vl.vslawzx.vvvvl (IntrinsicsVEVL.gen.td:485)
    ve_vl_vsll_vvsl,                           // llvm.ve.vl.vsll.vvsl (IntrinsicsVEVL.gen.td:456)
    ve_vl_vsll_vvsmvl,                         // llvm.ve.vl.vsll.vvsmvl (IntrinsicsVEVL.gen.td:459)
    ve_vl_vsll_vvsvl,                          // llvm.ve.vl.vsll.vvsvl (IntrinsicsVEVL.gen.td:457)
    ve_vl_vsll_vvvl,                           // llvm.ve.vl.vsll.vvvl (IntrinsicsVEVL.gen.td:454)
    ve_vl_vsll_vvvmvl,                         // llvm.ve.vl.vsll.vvvmvl (IntrinsicsVEVL.gen.td:458)
    ve_vl_vsll_vvvvl,                          // llvm.ve.vl.vsll.vvvvl (IntrinsicsVEVL.gen.td:455)
    ve_vl_vsral_vvsl,                          // llvm.ve.vl.vsral.vvsl (IntrinsicsVEVL.gen.td:522)
    ve_vl_vsral_vvsmvl,                        // llvm.ve.vl.vsral.vvsmvl (IntrinsicsVEVL.gen.td:525)
    ve_vl_vsral_vvsvl,                         // llvm.ve.vl.vsral.vvsvl (IntrinsicsVEVL.gen.td:523)
    ve_vl_vsral_vvvl,                          // llvm.ve.vl.vsral.vvvl (IntrinsicsVEVL.gen.td:520)
    ve_vl_vsral_vvvmvl,                        // llvm.ve.vl.vsral.vvvmvl (IntrinsicsVEVL.gen.td:524)
    ve_vl_vsral_vvvvl,                         // llvm.ve.vl.vsral.vvvvl (IntrinsicsVEVL.gen.td:521)
    ve_vl_vsrawsx_vvsl,                        // llvm.ve.vl.vsrawsx.vvsl (IntrinsicsVEVL.gen.td:504)
    ve_vl_vsrawsx_vvsmvl,                      // llvm.ve.vl.vsrawsx.vvsmvl (IntrinsicsVEVL.gen.td:507)
    ve_vl_vsrawsx_vvsvl,                       // llvm.ve.vl.vsrawsx.vvsvl (IntrinsicsVEVL.gen.td:505)
    ve_vl_vsrawsx_vvvl,                        // llvm.ve.vl.vsrawsx.vvvl (IntrinsicsVEVL.gen.td:502)
    ve_vl_vsrawsx_vvvmvl,                      // llvm.ve.vl.vsrawsx.vvvmvl (IntrinsicsVEVL.gen.td:506)
    ve_vl_vsrawsx_vvvvl,                       // llvm.ve.vl.vsrawsx.vvvvl (IntrinsicsVEVL.gen.td:503)
    ve_vl_vsrawzx_vvsl,                        // llvm.ve.vl.vsrawzx.vvsl (IntrinsicsVEVL.gen.td:510)
    ve_vl_vsrawzx_vvsmvl,                      // llvm.ve.vl.vsrawzx.vvsmvl (IntrinsicsVEVL.gen.td:513)
    ve_vl_vsrawzx_vvsvl,                       // llvm.ve.vl.vsrawzx.vvsvl (IntrinsicsVEVL.gen.td:511)
    ve_vl_vsrawzx_vvvl,                        // llvm.ve.vl.vsrawzx.vvvl (IntrinsicsVEVL.gen.td:508)
    ve_vl_vsrawzx_vvvmvl,                      // llvm.ve.vl.vsrawzx.vvvmvl (IntrinsicsVEVL.gen.td:512)
    ve_vl_vsrawzx_vvvvl,                       // llvm.ve.vl.vsrawzx.vvvvl (IntrinsicsVEVL.gen.td:509)
    ve_vl_vsrl_vvsl,                           // llvm.ve.vl.vsrl.vvsl (IntrinsicsVEVL.gen.td:468)
    ve_vl_vsrl_vvsmvl,                         // llvm.ve.vl.vsrl.vvsmvl (IntrinsicsVEVL.gen.td:471)
    ve_vl_vsrl_vvsvl,                          // llvm.ve.vl.vsrl.vvsvl (IntrinsicsVEVL.gen.td:469)
    ve_vl_vsrl_vvvl,                           // llvm.ve.vl.vsrl.vvvl (IntrinsicsVEVL.gen.td:466)
    ve_vl_vsrl_vvvmvl,                         // llvm.ve.vl.vsrl.vvvmvl (IntrinsicsVEVL.gen.td:470)
    ve_vl_vsrl_vvvvl,                          // llvm.ve.vl.vsrl.vvvvl (IntrinsicsVEVL.gen.td:467)
    ve_vl_vst_vssl,                            // llvm.ve.vl.vst.vssl (IntrinsicsVEVL.gen.td:33)
    ve_vl_vst_vssml,                           // llvm.ve.vl.vst.vssml (IntrinsicsVEVL.gen.td:34)
    ve_vl_vst2d_vssl,                          // llvm.ve.vl.vst2d.vssl (IntrinsicsVEVL.gen.td:57)
    ve_vl_vst2d_vssml,                         // llvm.ve.vl.vst2d.vssml (IntrinsicsVEVL.gen.td:58)
    ve_vl_vst2dnc_vssl,                        // llvm.ve.vl.vst2dnc.vssl (IntrinsicsVEVL.gen.td:59)
    ve_vl_vst2dnc_vssml,                       // llvm.ve.vl.vst2dnc.vssml (IntrinsicsVEVL.gen.td:60)
    ve_vl_vst2dncot_vssl,                      // llvm.ve.vl.vst2dncot.vssl (IntrinsicsVEVL.gen.td:63)
    ve_vl_vst2dncot_vssml,                     // llvm.ve.vl.vst2dncot.vssml (IntrinsicsVEVL.gen.td:64)
    ve_vl_vst2dot_vssl,                        // llvm.ve.vl.vst2dot.vssl (IntrinsicsVEVL.gen.td:61)
    ve_vl_vst2dot_vssml,                       // llvm.ve.vl.vst2dot.vssml (IntrinsicsVEVL.gen.td:62)
    ve_vl_vstl_vssl,                           // llvm.ve.vl.vstl.vssl (IntrinsicsVEVL.gen.td:49)
    ve_vl_vstl_vssml,                          // llvm.ve.vl.vstl.vssml (IntrinsicsVEVL.gen.td:50)
    ve_vl_vstl2d_vssl,                         // llvm.ve.vl.vstl2d.vssl (IntrinsicsVEVL.gen.td:73)
    ve_vl_vstl2d_vssml,                        // llvm.ve.vl.vstl2d.vssml (IntrinsicsVEVL.gen.td:74)
    ve_vl_vstl2dnc_vssl,                       // llvm.ve.vl.vstl2dnc.vssl (IntrinsicsVEVL.gen.td:75)
    ve_vl_vstl2dnc_vssml,                      // llvm.ve.vl.vstl2dnc.vssml (IntrinsicsVEVL.gen.td:76)
    ve_vl_vstl2dncot_vssl,                     // llvm.ve.vl.vstl2dncot.vssl (IntrinsicsVEVL.gen.td:79)
    ve_vl_vstl2dncot_vssml,                    // llvm.ve.vl.vstl2dncot.vssml (IntrinsicsVEVL.gen.td:80)
    ve_vl_vstl2dot_vssl,                       // llvm.ve.vl.vstl2dot.vssl (IntrinsicsVEVL.gen.td:77)
    ve_vl_vstl2dot_vssml,                      // llvm.ve.vl.vstl2dot.vssml (IntrinsicsVEVL.gen.td:78)
    ve_vl_vstlnc_vssl,                         // llvm.ve.vl.vstlnc.vssl (IntrinsicsVEVL.gen.td:51)
    ve_vl_vstlnc_vssml,                        // llvm.ve.vl.vstlnc.vssml (IntrinsicsVEVL.gen.td:52)
    ve_vl_vstlncot_vssl,                       // llvm.ve.vl.vstlncot.vssl (IntrinsicsVEVL.gen.td:55)
    ve_vl_vstlncot_vssml,                      // llvm.ve.vl.vstlncot.vssml (IntrinsicsVEVL.gen.td:56)
    ve_vl_vstlot_vssl,                         // llvm.ve.vl.vstlot.vssl (IntrinsicsVEVL.gen.td:53)
    ve_vl_vstlot_vssml,                        // llvm.ve.vl.vstlot.vssml (IntrinsicsVEVL.gen.td:54)
    ve_vl_vstnc_vssl,                          // llvm.ve.vl.vstnc.vssl (IntrinsicsVEVL.gen.td:35)
    ve_vl_vstnc_vssml,                         // llvm.ve.vl.vstnc.vssml (IntrinsicsVEVL.gen.td:36)
    ve_vl_vstncot_vssl,                        // llvm.ve.vl.vstncot.vssl (IntrinsicsVEVL.gen.td:39)
    ve_vl_vstncot_vssml,                       // llvm.ve.vl.vstncot.vssml (IntrinsicsVEVL.gen.td:40)
    ve_vl_vstot_vssl,                          // llvm.ve.vl.vstot.vssl (IntrinsicsVEVL.gen.td:37)
    ve_vl_vstot_vssml,                         // llvm.ve.vl.vstot.vssml (IntrinsicsVEVL.gen.td:38)
    ve_vl_vstu_vssl,                           // llvm.ve.vl.vstu.vssl (IntrinsicsVEVL.gen.td:41)
    ve_vl_vstu_vssml,                          // llvm.ve.vl.vstu.vssml (IntrinsicsVEVL.gen.td:42)
    ve_vl_vstu2d_vssl,                         // llvm.ve.vl.vstu2d.vssl (IntrinsicsVEVL.gen.td:65)
    ve_vl_vstu2d_vssml,                        // llvm.ve.vl.vstu2d.vssml (IntrinsicsVEVL.gen.td:66)
    ve_vl_vstu2dnc_vssl,                       // llvm.ve.vl.vstu2dnc.vssl (IntrinsicsVEVL.gen.td:67)
    ve_vl_vstu2dnc_vssml,                      // llvm.ve.vl.vstu2dnc.vssml (IntrinsicsVEVL.gen.td:68)
    ve_vl_vstu2dncot_vssl,                     // llvm.ve.vl.vstu2dncot.vssl (IntrinsicsVEVL.gen.td:71)
    ve_vl_vstu2dncot_vssml,                    // llvm.ve.vl.vstu2dncot.vssml (IntrinsicsVEVL.gen.td:72)
    ve_vl_vstu2dot_vssl,                       // llvm.ve.vl.vstu2dot.vssl (IntrinsicsVEVL.gen.td:69)
    ve_vl_vstu2dot_vssml,                      // llvm.ve.vl.vstu2dot.vssml (IntrinsicsVEVL.gen.td:70)
    ve_vl_vstunc_vssl,                         // llvm.ve.vl.vstunc.vssl (IntrinsicsVEVL.gen.td:43)
    ve_vl_vstunc_vssml,                        // llvm.ve.vl.vstunc.vssml (IntrinsicsVEVL.gen.td:44)
    ve_vl_vstuncot_vssl,                       // llvm.ve.vl.vstuncot.vssl (IntrinsicsVEVL.gen.td:47)
    ve_vl_vstuncot_vssml,                      // llvm.ve.vl.vstuncot.vssml (IntrinsicsVEVL.gen.td:48)
    ve_vl_vstuot_vssl,                         // llvm.ve.vl.vstuot.vssl (IntrinsicsVEVL.gen.td:45)
    ve_vl_vstuot_vssml,                        // llvm.ve.vl.vstuot.vssml (IntrinsicsVEVL.gen.td:46)
    ve_vl_vsubsl_vsvl,                         // llvm.ve.vl.vsubsl.vsvl (IntrinsicsVEVL.gen.td:189)
    ve_vl_vsubsl_vsvmvl,                       // llvm.ve.vl.vsubsl.vsvmvl (IntrinsicsVEVL.gen.td:192)
    ve_vl_vsubsl_vsvvl,                        // llvm.ve.vl.vsubsl.vsvvl (IntrinsicsVEVL.gen.td:190)
    ve_vl_vsubsl_vvvl,                         // llvm.ve.vl.vsubsl.vvvl (IntrinsicsVEVL.gen.td:187)
    ve_vl_vsubsl_vvvmvl,                       // llvm.ve.vl.vsubsl.vvvmvl (IntrinsicsVEVL.gen.td:191)
    ve_vl_vsubsl_vvvvl,                        // llvm.ve.vl.vsubsl.vvvvl (IntrinsicsVEVL.gen.td:188)
    ve_vl_vsubswsx_vsvl,                       // llvm.ve.vl.vsubswsx.vsvl (IntrinsicsVEVL.gen.td:171)
    ve_vl_vsubswsx_vsvmvl,                     // llvm.ve.vl.vsubswsx.vsvmvl (IntrinsicsVEVL.gen.td:174)
    ve_vl_vsubswsx_vsvvl,                      // llvm.ve.vl.vsubswsx.vsvvl (IntrinsicsVEVL.gen.td:172)
    ve_vl_vsubswsx_vvvl,                       // llvm.ve.vl.vsubswsx.vvvl (IntrinsicsVEVL.gen.td:169)
    ve_vl_vsubswsx_vvvmvl,                     // llvm.ve.vl.vsubswsx.vvvmvl (IntrinsicsVEVL.gen.td:173)
    ve_vl_vsubswsx_vvvvl,                      // llvm.ve.vl.vsubswsx.vvvvl (IntrinsicsVEVL.gen.td:170)
    ve_vl_vsubswzx_vsvl,                       // llvm.ve.vl.vsubswzx.vsvl (IntrinsicsVEVL.gen.td:177)
    ve_vl_vsubswzx_vsvmvl,                     // llvm.ve.vl.vsubswzx.vsvmvl (IntrinsicsVEVL.gen.td:180)
    ve_vl_vsubswzx_vsvvl,                      // llvm.ve.vl.vsubswzx.vsvvl (IntrinsicsVEVL.gen.td:178)
    ve_vl_vsubswzx_vvvl,                       // llvm.ve.vl.vsubswzx.vvvl (IntrinsicsVEVL.gen.td:175)
    ve_vl_vsubswzx_vvvmvl,                     // llvm.ve.vl.vsubswzx.vvvmvl (IntrinsicsVEVL.gen.td:179)
    ve_vl_vsubswzx_vvvvl,                      // llvm.ve.vl.vsubswzx.vvvvl (IntrinsicsVEVL.gen.td:176)
    ve_vl_vsubul_vsvl,                         // llvm.ve.vl.vsubul.vsvl (IntrinsicsVEVL.gen.td:153)
    ve_vl_vsubul_vsvmvl,                       // llvm.ve.vl.vsubul.vsvmvl (IntrinsicsVEVL.gen.td:156)
    ve_vl_vsubul_vsvvl,                        // llvm.ve.vl.vsubul.vsvvl (IntrinsicsVEVL.gen.td:154)
    ve_vl_vsubul_vvvl,                         // llvm.ve.vl.vsubul.vvvl (IntrinsicsVEVL.gen.td:151)
    ve_vl_vsubul_vvvmvl,                       // llvm.ve.vl.vsubul.vvvmvl (IntrinsicsVEVL.gen.td:155)
    ve_vl_vsubul_vvvvl,                        // llvm.ve.vl.vsubul.vvvvl (IntrinsicsVEVL.gen.td:152)
    ve_vl_vsubuw_vsvl,                         // llvm.ve.vl.vsubuw.vsvl (IntrinsicsVEVL.gen.td:159)
    ve_vl_vsubuw_vsvmvl,                       // llvm.ve.vl.vsubuw.vsvmvl (IntrinsicsVEVL.gen.td:162)
    ve_vl_vsubuw_vsvvl,                        // llvm.ve.vl.vsubuw.vsvvl (IntrinsicsVEVL.gen.td:160)
    ve_vl_vsubuw_vvvl,                         // llvm.ve.vl.vsubuw.vvvl (IntrinsicsVEVL.gen.td:157)
    ve_vl_vsubuw_vvvmvl,                       // llvm.ve.vl.vsubuw.vvvmvl (IntrinsicsVEVL.gen.td:161)
    ve_vl_vsubuw_vvvvl,                        // llvm.ve.vl.vsubuw.vvvvl (IntrinsicsVEVL.gen.td:158)
    ve_vl_vsuml_vvl,                           // llvm.ve.vl.vsuml.vvl (IntrinsicsVEVL.gen.td:1127)
    ve_vl_vsuml_vvml,                          // llvm.ve.vl.vsuml.vvml (IntrinsicsVEVL.gen.td:1128)
    ve_vl_vsumwsx_vvl,                         // llvm.ve.vl.vsumwsx.vvl (IntrinsicsVEVL.gen.td:1123)
    ve_vl_vsumwsx_vvml,                        // llvm.ve.vl.vsumwsx.vvml (IntrinsicsVEVL.gen.td:1124)
    ve_vl_vsumwzx_vvl,                         // llvm.ve.vl.vsumwzx.vvl (IntrinsicsVEVL.gen.td:1125)
    ve_vl_vsumwzx_vvml,                        // llvm.ve.vl.vsumwzx.vvml (IntrinsicsVEVL.gen.td:1126)
    ve_vl_vxor_vsvl,                           // llvm.ve.vl.vxor.vsvl (IntrinsicsVEVL.gen.td:388)
    ve_vl_vxor_vsvmvl,                         // llvm.ve.vl.vxor.vsvmvl (IntrinsicsVEVL.gen.td:391)
    ve_vl_vxor_vsvvl,                          // llvm.ve.vl.vxor.vsvvl (IntrinsicsVEVL.gen.td:389)
    ve_vl_vxor_vvvl,                           // llvm.ve.vl.vxor.vvvl (IntrinsicsVEVL.gen.td:386)
    ve_vl_vxor_vvvmvl,                         // llvm.ve.vl.vxor.vvvmvl (IntrinsicsVEVL.gen.td:390)
    ve_vl_vxor_vvvvl,                          // llvm.ve.vl.vxor.vvvvl (IntrinsicsVEVL.gen.td:387)
    ve_vl_xorm_MMM,                            // llvm.ve.vl.xorm.MMM (IntrinsicsVEVL.gen.td:1240)
    ve_vl_xorm_mmm,                            // llvm.ve.vl.xorm.mmm (IntrinsicsVEVL.gen.td:1239)
}; // enum
} // namespace llvm::Intrinsic
#endif

